@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -203,7 +203,7 @@ void AccountDialog::askForToken()
         // Show message about the web browser that will be started
         this->errorsLabel->setText("[ " + tr("A web browser will start now, where you can get the verifier code") + " ]");
 
-        this->pController->setNewUserID(userIDLineEdit->text());
+        this->pController->setNewUserId(userIDLineEdit->text());
         this->pController->getToken();
     }
     else // userID does not match user@hostname.domain
