@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -40,49 +40,29 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     this->setWindowIcon(QIcon::fromTheme("system-users"));
     this->setWindowFlags(Qt::Window);
     this->setWindowModality(Qt::WindowModal);
-    this->setMinimumSize(200, 200);
+    this->setMinimumSize(300, 300);
 
-    this->pController = pumpController;
-    connect(pController, SIGNAL(contactListReceived(QString,QVariantList)),
-            this, SLOT(updateAllContactsList(QString,QVariantList)));
 
 
     // Left side, all contacts, with filter
+    this->peopleWidget = new PeopleWidget(tr("&Add to Selected") + " >>",
+                                          PeopleWidget::EmbeddedWidget,
+                                          pumpController);
+    connect(peopleWidget, SIGNAL(contactSelected(QString)),
+            this, SLOT(copyToSelected(QString)));
+    connect(peopleWidget, SIGNAL(addButtonPressed(QString)),
+            this, SLOT(copyToSelected(QString)));
 
-    this->searchLabel = new QLabel(tr("&Search:"));
-    this->searchLineEdit = new QLineEdit();
-    searchLineEdit->setPlaceholderText(tr("Enter a name here to search for it"));
-    searchLabel->setBuddy(searchLineEdit);
-    connect(searchLineEdit, SIGNAL(textChanged(QString)),
-            this, SLOT(filterList(QString)));
 
-    allContactsListWidget = new QListWidget();
-    allContactsListWidget->setDragDropMode(QListView::DragDrop);
-    allContactsListWidget->setDefaultDropAction(Qt::CopyAction);
-    allContactsListWidget->setSelectionMode(QListView::ExtendedSelection);
-    allContactsListWidget->setSortingEnabled(true);
-    connect(allContactsListWidget, SIGNAL(activated(QModelIndex)),
-            this, SLOT(copyClickedToSelected(QModelIndex)));
-
-    addToSelectedButton = new QPushButton(QIcon::fromTheme("list-add"),
-                                          tr("&Add to Selected") + " >>");
-    connect(addToSelectedButton, SIGNAL(clicked()),
-            this, SLOT(copyToSelected()));
 
     this->allGroupboxLayout = new QVBoxLayout();
-    allGroupboxLayout->addWidget(searchLabel);
-    allGroupboxLayout->addWidget(searchLineEdit);
-    allGroupboxLayout->addSpacing(2);
-    allGroupboxLayout->addWidget(allContactsListWidget);
-    allGroupboxLayout->addSpacing(4);
-    allGroupboxLayout->addWidget(addToSelectedButton);
+    allGroupboxLayout->addWidget(peopleWidget);
 
     allContactsGroupbox = new QGroupBox(tr("All Contacts"));
     allContactsGroupbox->setLayout(allGroupboxLayout);
 
 
     // Right side, selected contacts
-
     explanationLabel = new QLabel(tr("Select people from the list on the left.\n"
                                      "You can drag them with the mouse, click or "
                                      "double-click on them, or select them and "
@@ -130,10 +110,7 @@ AudienceSelector::AudienceSelector(PumpController *pumpController,
     mainLayout->addWidget(selectedListGroupbox, 4);
     this->setLayout(mainLayout);
 
-
-    this->filterList(""); // Populate the list without filter, initially
-
-    qDebug() << "AudienceSelector created";
+    qDebug() << "AudienceSelector created" << titlePart;
 }
 
 
@@ -151,9 +128,7 @@ AudienceSelector::~AudienceSelector()
 void AudienceSelector::resetLists()
 {
     this->selectedListWidget->clear();
-
-    this->searchLineEdit->clear(); // might also trigger filterLists()
-    this->allContactsListWidget->scrollToTop();
+    this->peopleWidget->resetWidget();
 }
 
 
@@ -178,80 +153,23 @@ void AudienceSelector::keyPressEvent(QKeyEvent *event)
 //////////////////////////////////////////////////////////////////////////////
 
 
-/*
- * Filter the list of all contacts based on what
- * the user entered in the search box
- *
- */
-void AudienceSelector::filterList(QString searchTerms)
-{
-    allContactsListWidget->clear();
-
-    allContactsListWidget->addItems(allContactsStringList.filter(searchTerms,
-                                                                 Qt::CaseInsensitive));
-}
-
-
-/*
- * Update the list of all contacts (actually, 'following')
- * from the PumpController
- *
- */
-void AudienceSelector::updateAllContactsList(QString listType,
-                                             QVariantList contactsVariantList)
-{
-    if (listType != "following")
-    {
-        return;
-    }
-    qDebug() << "AudienceSelector: received list of Following; updating...";
-
-    allContactsStringList.clear();
-
-    QString singleContactString;
-    foreach (QVariant contact, contactsVariantList)
-    {
-        singleContactString = contact.toMap().value("displayName").toString();
-        singleContactString.append("  <");
-        singleContactString.append(contact.toMap().value("id").toString().remove(0,5));
-        singleContactString.append(">");
-
-        allContactsStringList.append(singleContactString);
-    }
-
-
-    // Populate the list widget, using whatever filter is set
-    this->filterList(searchLineEdit->text());
-}
-
-
-
-/*
- * Copy a contact to the list of Selected People
- *
- * Used when selecting a row and clicking the "add" button
- */
-void AudienceSelector::copyToSelected()
-{
-    // if something is selected...
-    if (this->allContactsListWidget->currentRow() != -1)
-    {
-        this->selectedListWidget->addItem(allContactsListWidget->currentItem()->data(0).toString());
-    }
-}
-
 
 /*
  * Copy a contact to the list of Selected
  *
- * Used when double-clicking on it
+ * The contact string comes in a SIGNAL from PeopleWidget
+ *
  */
-void AudienceSelector::copyClickedToSelected(QModelIndex modelIndex)
+void AudienceSelector::copyToSelected(QString contactString)
 {
-    this->selectedListWidget->addItem(modelIndex.data().toString());
+    if (!contactString.isEmpty())
+    {
+        this->selectedListWidget->addItem(contactString);
+    }
 }
 
 
+
 /*
  * The "Done" button: emit signal with list of selected people
  *
