@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -35,6 +35,7 @@
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "peoplewidget.h"
 
 
 class AudienceSelector : public QFrame
@@ -59,19 +60,13 @@ signals:
 
 
 public slots:
-    void filterList(QString searchTerms);
-    void updateAllContactsList(QString listType,
-                               QVariantList contactsVariantList);
-    void copyToSelected();
-    void copyClickedToSelected(QModelIndex modelIndex);
+    void copyToSelected(QString contactString);
 
     void setAudience();
 
 
 
 private:
-    PumpController *pController;
-
     QString selectorType;
 
     QHBoxLayout *mainLayout;
@@ -80,15 +75,7 @@ private:
     QVBoxLayout *allGroupboxLayout;
     QGroupBox *allContactsGroupbox;
 
-    QLabel *searchLabel;
-    QLineEdit *searchLineEdit;
-    QListWidget *allContactsListWidget;
-
-    QStringList allContactsStringList;
-
-    QPushButton *addToSelectedButton;
-
-
+    PeopleWidget *peopleWidget;
 
     QVBoxLayout *selectedGroupboxLayout;
     QGroupBox *selectedListGroupbox;
