@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ Comment::Comment(PumpController *pumpController,
 
     QString commentAuthorID = commentAuthorMap.value("id").toString();
     commentAuthorID.remove(0, 5); // remove "acct:" at the beginning
-    if (commentAuthorID == pController->currentUserID())
+    if (commentAuthorID == pController->currentUserId())
     {
         commentIsOwn = true; // Comment is ours!
 
@@ -67,7 +67,7 @@ Comment::Comment(PumpController *pumpController,
     if (QFile::exists(commentAuthorAvatarFile))
     {
         avatarLabel->setPixmap(QPixmap(commentAuthorAvatarFile)
-                               .scaledToHeight(32, Qt::SmoothTransformation));
+                               .scaledToWidth(32, Qt::SmoothTransformation));
     }
     else
     {
@@ -456,7 +456,7 @@ void Comment::showUrlInfo(QString url)
     if (avatarUrl == this->commentAuthorAvatarUrl)
     {
         avatarLabel->setPixmap(QPixmap(avatarFilename)
-                               .scaledToHeight(32, Qt::SmoothTransformation));
+                               .scaledToWidth(32, Qt::SmoothTransformation));
 
         disconnect(pController, SIGNAL(avatarStored(QString,QString)),
                    this, SLOT(redrawAvatar(QString,QString)));
