@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -77,6 +77,10 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     connect(commentComposer, SIGNAL(editingCancelled()), this, SLOT(setMinimumMode()));
 
 
+    // Formatting/Tools button exported from Composer
+    this->toolsButton = commentComposer->getToolsButton();
+
+
     // Info label about sending status
     this->statusInfoLabel = new QLabel();
     statusInfoLabel->setAlignment(Qt::AlignCenter);
@@ -102,10 +106,11 @@ CommenterBlock::CommenterBlock(PumpController *pumpController,
     mainLayout = new QGridLayout();
     mainLayout->addWidget(showAllCommentsLinkLabel, 0, 0, 1, 4, Qt::AlignRight | Qt::AlignTop);
     mainLayout->addWidget(commentsScrollArea,       1, 0, 1, 4);
-    mainLayout->addWidget(commentComposer,          2, 0, 3, 3);
-    mainLayout->addWidget(statusInfoLabel,          2, 3, 1, 1, Qt::AlignCenter);
-    mainLayout->addWidget(commentButton,            3, 3, 1, 1);
-    mainLayout->addWidget(cancelButton,             4, 3, 1, 1);
+    mainLayout->addWidget(commentComposer,          2, 0, 4, 3);
+    mainLayout->addWidget(toolsButton,              2, 3, 1, 1);
+    mainLayout->addWidget(statusInfoLabel,          3, 3, 1, 1, Qt::AlignCenter);
+    mainLayout->addWidget(commentButton,            4, 3, 1, 1);
+    mainLayout->addWidget(cancelButton,             5, 3, 1, 1);
     this->setLayout(mainLayout);
 
 
@@ -210,6 +215,7 @@ void CommenterBlock::resizeEvent(QResizeEvent *event)
 void CommenterBlock::setMinimumMode()
 {
     this->commentComposer->hide();
+    this->toolsButton->hide();
     statusInfoLabel->clear();
     this->statusInfoLabel->hide();
     this->commentButton->hide();
@@ -227,6 +233,7 @@ void CommenterBlock::setMinimumMode()
 void CommenterBlock::setFullMode(QString initialText)
 {
     this->commentComposer->show();
+    this->toolsButton->show();
     this->statusInfoLabel->show();
     this->commentButton->show();
     this->cancelButton->show();
