@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@
 
 #include <QTextEdit>
 #include <QFocusEvent>
-#include <QGridLayout>
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QPushButton>
 #include <QMenu>
@@ -46,6 +46,8 @@ public:
     void erase();
     void insertLink(QString url, QString title="");
 
+    int getMessageLabelHeight();
+
 signals:
     void focusReceived();
     void editingFinished();
@@ -70,6 +72,7 @@ public slots:
 
     void cancelPost();
 
+    QPushButton *getToolsButton();
 
 protected:
     virtual void focusInEvent(QFocusEvent *event);
@@ -78,7 +81,7 @@ protected:
     virtual void insertFromMimeData(const QMimeData *source);
 
 private:
-    QGridLayout *mainLayout;
+    QHBoxLayout *mainLayout;
 
     QLabel *startConversationLabel;
     QPushButton *toolsButton;
