@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -20,10 +20,11 @@
 
 #include "configdialog.h"
 
-ConfigDialog::ConfigDialog(QString dataDirectory,
-                           int updateInterval, int postsPerPage, int tabsPosition,
-                           bool tabsMovable, int publisherType, bool publicPosts,
-                           int showNotifications, QWidget *parent) : QWidget(parent)
+ConfigDialog::ConfigDialog(QString dataDirectory, int updateInterval,
+                           int postsPerPageMain, int postsPerPageOther,
+                           int tabsPosition, bool tabsMovable,
+                           bool publicPosts, int showNotifications,
+                           QWidget *parent) : QWidget(parent)
 {
     this->setWindowTitle("Dianara - " + tr("Program Configuration"));
     this->setWindowIcon(QIcon::fromTheme("configure"));
@@ -42,11 +43,21 @@ ConfigDialog::ConfigDialog(QString dataDirectory,
     updateIntervalSpinbox->setValue(updateInterval);
     optionsLayout->addRow(tr("Timeline &update interval"), updateIntervalSpinbox);
 
-    postsPerPageSpinbox = new QSpinBox();
-    postsPerPageSpinbox->setRange(10, 100); // 10-100 ppp
-    postsPerPageSpinbox->setSuffix(" "+ tr("posts"));
-    postsPerPageSpinbox->setValue(postsPerPage);
-    optionsLayout->addRow(tr("&Posts per page"), postsPerPageSpinbox);
+    postsPerPageMainSpinbox = new QSpinBox();
+    postsPerPageMainSpinbox->setRange(5, 100); // 5-100 ppp
+    postsPerPageMainSpinbox->setSuffix(" "+ tr("posts",
+                                               "Goes after a number, as: 25 posts"));
+    postsPerPageMainSpinbox->setValue(postsPerPageMain);
+    optionsLayout->addRow(tr("&Posts per page, main timeline"),
+                          postsPerPageMainSpinbox);
+
+    postsPerPageOtherSpinbox = new QSpinBox();
+    postsPerPageOtherSpinbox->setRange(5, 100); // 5-100 ppp
+    postsPerPageOtherSpinbox->setSuffix(" "+ tr("posts",
+                                                "This goes after a number, like: 10 posts"));
+    postsPerPageOtherSpinbox->setValue(postsPerPageOther);
+    optionsLayout->addRow(tr("Posts per page, &other timelines"),
+                          postsPerPageOtherSpinbox);
 
 
     tabsPositionCombobox = new QComboBox();
@@ -67,15 +78,6 @@ ConfigDialog::ConfigDialog(QString dataDirectory,
     optionsLayout->addRow(tr("&Movable tabs"), tabsMovableCheckbox);
 
 
-    publisherTypeCombobox = new QComboBox();
-    publisherTypeCombobox->addItem(tr("Buttons below"));
-    publisherTypeCombobox->addItem(tr("Buttons around"));
-    publisherTypeCombobox->addItem(tr("Buttons on right side"));
-    publisherTypeCombobox->setCurrentIndex(publisherType);
-    publisherTypeCombobox->setToolTip(tr("Restart program to apply this change"));
-    optionsLayout->addRow(tr("C&omposer type"), publisherTypeCombobox);
-
-
     publicPostsCheckbox = new QCheckBox();
     publicPostsCheckbox->setChecked(publicPosts);
     optionsLayout->addRow(tr("Public posts as &default"), publicPostsCheckbox);
@@ -150,10 +152,10 @@ ConfigDialog::~ConfigDialog()
 void ConfigDialog::saveConfiguration()
 {
     emit configurationChanged(updateIntervalSpinbox->value(),
-                              postsPerPageSpinbox->value(),
+                              postsPerPageMainSpinbox->value(),
+                              postsPerPageOtherSpinbox->value(),
                               tabsPositionCombobox->currentIndex(),
                               tabsMovableCheckbox->isChecked(),
-                              publisherTypeCombobox->currentIndex(),
                               publicPostsCheckbox->isChecked(),
                               showNotificationsCombobox->currentIndex());
     qDebug() << "ConfigDialog: config saved";
