@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -41,10 +41,10 @@ class ConfigDialog : public QWidget
 public:
     ConfigDialog(QString dataDirectory,
                  int updateInterval,
-                 int postsPerPage,
+                 int postsPerPageMain,
+                 int postsPerPageOther,
                  int tabsPosition,
                  bool tabsMovable,
-                 int publisherType,
                  bool publicPosts,
                  int showNotifications,
                  QWidget *parent);
@@ -53,10 +53,10 @@ public:
 
 signals:
     void configurationChanged(int newUpdateInterval,
-                              int newPostsPerPage,
+                              int newPostsPerPageMain,
+                              int newPostsPerPageOther,
                               int newTabsPosition,
                               bool newTabsMovable,
-                              int newPublisherType,
                               bool newPublicPosts,
                               int newShowNotifications);
 
@@ -71,10 +71,10 @@ private:
     QFormLayout *optionsLayout;
 
     QSpinBox *updateIntervalSpinbox;
-    QSpinBox *postsPerPageSpinbox;
+    QSpinBox *postsPerPageMainSpinbox;
+    QSpinBox *postsPerPageOtherSpinbox;
     QComboBox *tabsPositionCombobox;
     QCheckBox *tabsMovableCheckbox;
-    QComboBox *publisherTypeCombobox;
     QCheckBox *publicPostsCheckbox;
     QComboBox *showNotificationsCombobox;
 
