@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -142,16 +142,14 @@ ContactCard::ContactCard(PumpController *pumpController,
 
     addToListMenu = new QMenu(tr("In Lists..."));
     addToListMenu->setIcon(QIcon::fromTheme("format-list-unordered"));
-    addToListMenu->addAction("fake list 1")->setCheckable(true);
+    addToListMenu->addAction("fake list 1")->setCheckable(true); // FIXME...
     addToListMenu->addAction("fake list 2")->setCheckable(true);
     addToListMenu->addAction("fake list 3")->setCheckable(true);
-    addToListMenu->addAction("fake list 4")->setCheckable(true);
-    addToListMenu->addAction("fake list 5")->setCheckable(true);
 
     optionsMenu = new QMenu("*options*");
     optionsMenu->addAction(openProfileAction);
-    optionsMenu->addMenu(addToListMenu);
-    addToListMenu->setDisabled(true); // TMP/FIXME: disabled until implemented
+    //optionsMenu->addMenu(addToListMenu); // Don't include it for now, until 1.2 FIXME
+
 
     optionsButton = new QPushButton(QIcon::fromTheme("user-properties"),
                                     tr("User Options"));
