@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -263,19 +263,29 @@ void ContactList::exportContactsToFile(QString listType)
 
 
 
-void ContactList::setContactListContents(QString listType, QVariantList contactList)
+void ContactList::setContactListContents(QString listType,
+                                         QVariantList contactList,
+                                         int totalReceivedCount)
 {
     qDebug() << "Setting contact list contents";
 
     if (listType == "following")
     {
-        this->clearFollowingListContents();
-        this->followingCount = contactList.size();
+        if (totalReceivedCount == 200) // Only for the first batch
+        {
+            this->clearFollowingListContents();
+            followingCount = 0;
+        }
+        this->followingCount += contactList.size();
     }
     else
     {
-        this->clearFollowersListContents();
-        this->followersCount = contactList.size();
+        if (totalReceivedCount == 200)
+        {
+            this->clearFollowersListContents();
+            followersCount = 0;
+        }
+        this->followersCount += contactList.size();
     }
 
 
@@ -323,6 +333,18 @@ void ContactList::setContactListContents(QString listType, QVariantList contactL
     if (listType == "following")
     {
         this->pController->updateInternalFollowingIdList(followingIdStringList);
+
+        if (totalReceivedCount < pController->currentFollowingCount())
+        {
+            pController->getContactList(listType, totalReceivedCount);
+        }
+    }
+    else  // followers
+    {
+        if (totalReceivedCount < pController->currentFollowersCount())
+        {
+            pController->getContactList(listType, totalReceivedCount);
+        }
     }
 
 
