@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -61,7 +61,8 @@ signals:
 
 public slots:
     void setContactListContents(QString listType,
-                                QVariantList contactList);
+                                QVariantList contactList,
+                                int totalReceivedCount);
     void setListsListContents(QVariantList listsList);
 
     void refreshFollowing();
