@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,9 +31,13 @@
 #include <QPushButton>
 #include <QMessageBox>
 
+#include <QInputDialog> // TMP!!
+
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "peoplewidget.h"
+
 
 class ListsManager : public QWidget
 {
@@ -46,21 +50,39 @@ public:
 
     void setListsList(QVariantList listsList);
 
+
 signals:
 
+
 public slots:
+    void setPersonsInList(QVariantList personList, QString listUrl);
     void createList();
     void deleteList();
 
+    void enableDisableDeleteButtons();
+
+    void showAddPersonDialog();
+    void addPerson(QString contactString);
+    void removePerson();
+
+    void addPersonItemToList(QString personId, QString personName);
+    void removePersonItemFromList(QString personId);
+
 
 private:
     PumpController *pController;
 
     QVBoxLayout *mainLayout;
+    QHBoxLayout *buttonsLayout;
 
     QTreeWidget *listsTreeWidget;
     QPushButton *deleteListButton;
 
+    QPushButton *addPersonButton;
+    QPushButton *removePersonButton;
+
+    PeopleWidget *peopleWidget;
+
     QGroupBox *newListGroupbox;
     QHBoxLayout *groupboxMainLayout;
     QVBoxLayout *groupboxLeftLayout;
@@ -68,6 +90,8 @@ private:
     QLineEdit *newListNameLineEdit;
     QTextEdit *newListDescTextEdit;
     QPushButton *createListButton;
+
+    QStringList personListsUrlList;
 };
 
 
