@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -51,16 +51,22 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     ////// GUI
 
-    // Splitter to divide the window horizontally
-    mainSplitter = new QSplitter(Qt::Horizontal, this);
 
     // User's profile editor, in its own window
     profileEditor = new ProfileEditor(pumpController, this);
 
 
+    // Splitter to divide the window horizontally
+    mainSplitter = new QSplitter(Qt::Horizontal, this);
+    mainSplitter->setChildrenCollapsible(false);
+    mainSplitter->setContentsMargins(0, 0, 0, 0);
+    mainSplitter->setHandleWidth(4);
+
+
     // Left side
     leftSideWidget = new QWidget();
     leftLayout = new QVBoxLayout();
+    leftLayout->setContentsMargins(1, 1, 0, 1);
 
     avatarIconButton = new QPushButton();
     avatarIconButton->setIcon(QIcon(QPixmap(":/images/no-avatar.png")
@@ -73,13 +79,15 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     avatarIconButton->setIconSize(QSize(64, 64));
     connect(avatarIconButton, SIGNAL(clicked()),
             profileEditor, SLOT(show()));
-
     leftLayout->addWidget(avatarIconButton, 0, Qt::AlignLeft);
-    leftLayout->addSpacing(4);
 
-    fullNameLabel = new QLabel("[----------]");
+
+    userInfoLayout = new QVBoxLayout();
+    userInfoLayout->setContentsMargins(10, 0, 10, 0);
+
+    fullNameLabel = new QLabel("[---------------]");
     fullNameLabel->setWordWrap(true);
-    leftLayout->addWidget(fullNameLabel);
+    userInfoLayout->addWidget(fullNameLabel);
 
 
     QFont userDetailsFont;
@@ -90,7 +98,7 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     userIdLabel = new QLabel();
     userIdLabel->setWordWrap(true);
     userIdLabel->setFont(userDetailsFont);
-    leftLayout->addWidget(userIdLabel);
+    userInfoLayout->addWidget(userIdLabel);
 
     userDetailsFont.setBold(false);
     userDetailsFont.setItalic(false);
@@ -98,17 +106,21 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     userHometownLabel = new QLabel();
     userHometownLabel->setWordWrap(true);
     userHometownLabel->setFont(userDetailsFont);
-    leftLayout->addWidget(userHometownLabel);
-    leftLayout->addSpacing(8);
+    userInfoLayout->addWidget(userHometownLabel);
+
+    leftLayout->addLayout(userInfoLayout);
+
 
 
     leftPanel = new QToolBox(); // For now, only one "section"...
 
     meanwhileFeed = new MinorFeed(pumpController);
+    connect(meanwhileFeed, SIGNAL(newItemsCountChanged(int)),
+            this, SLOT(setMinorFeedTitle(int)));
     leftPanel->addItem(meanwhileFeed,
                        QIcon::fromTheme("clock"),
-                       tr("Meanwhile..."));
-
+                       "*meanwhile*");
+    this->setMinorFeedTitle(0); // Set initial title
     leftLayout->addWidget(leftPanel);
 
     this->leftSideWidget->setLayout(leftLayout);
@@ -118,9 +130,9 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     // Right side
     rightSideWidget = new QWidget();
     rightLayout = new QVBoxLayout();
+    rightLayout->setContentsMargins(0, 1, 1, 1);
 
-    this->publisherType = settings.value("Configuration/publisherType", 0).toInt(); // TMP/FIXME?
-    publisher = new Publisher(pumpController, publisherType);
+    publisher = new Publisher(pumpController);
 
 
     /// START SETTING UP TIMELINES
@@ -282,8 +294,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
     mainSplitter->addWidget(leftSideWidget);
     mainSplitter->addWidget(rightSideWidget);
-    mainSplitter->setHandleWidth(4);
-    mainSplitter->setChildrenCollapsible(false);
     this->setCentralWidget(mainSplitter);
 
 
@@ -314,18 +324,28 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     connect(accountDialog, SIGNAL(userIDChanged(QString)),
             this, SLOT(updateUserID(QString)));
 
+    // If this is the first run, show the account Dialog
+    if (firstRun)
+    {
+        accountDialog->show();
+    }
+
     // Configuration dialog
     configDialog = new ConfigDialog(this->dataDirectory,
                                     this->updateInterval,
-                                    this->postsPerPage,
+                                    this->postsPerPageMain,
+                                    this->postsPerPageOther,
                                     this->tabsPosition,
                                     this->tabsMovable,
-                                    this->publisherType,
                                     this->publicPosts,
                                     this->showNotifications,
                                     this);
-    connect(configDialog, SIGNAL(configurationChanged(int,int,int,bool,int,bool,int)),
-            this, SLOT(updateSettings(int,int,int,bool,int,bool,int)));
+    connect(configDialog, SIGNAL(configurationChanged(int,int,int,int,bool,bool,int)),
+            this, SLOT(updateSettings(int,int,int,int,bool,bool,int)));
+
+
+    // Filter editor
+    filterEditor = new FilterEditor(pumpController, this);
 
 
 
@@ -333,8 +353,8 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     //////////////////////////////// Connections for PumpController //////////
     ///
 
-    connect(pumpController, SIGNAL(profileReceived(QString,QString,QString,QString)),
-            this, SLOT(updateProfileData(QString,QString,QString,QString)));
+    connect(pumpController, SIGNAL(profileReceived(QString,QString,QString,QString,QString)),
+            this, SLOT(updateProfileData(QString,QString,QString,QString,QString)));
 
     connect(pumpController, SIGNAL(avatarPictureReceived(QByteArray,QUrl)),
             this, SLOT(storeAvatar(QByteArray,QUrl)));
@@ -395,15 +415,14 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
     // After receiving a contact list, update it
-    connect(pumpController, SIGNAL(contactListReceived(QString,QVariantList)),
-            contactList, SLOT(setContactListContents(QString,QVariantList)));
+    connect(pumpController, SIGNAL(contactListReceived(QString,QVariantList,int)),
+            contactList, SLOT(setContactListContents(QString,QVariantList,int)));
 
     // After receiving the list of lists, update it
     connect(pumpController, SIGNAL(listsListReceived(QVariantList)),
             contactList, SLOT(setListsListContents(QVariantList)));
 
 
-
     // Show notifications for events sent from pumpController
     connect(pumpController, SIGNAL(showNotification(QString)),
             fdNotifier, SLOT(showMessage(QString)));
@@ -414,14 +433,6 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
 
 
 
-    // Don't set PumpController in motion if no User ID is set!
-    if (!userID.isEmpty())
-    {
-        pumpController->setUserCredentials(this->userID);
-        // getUserProfile() will be called from setUserCredentials()
-    }
-
-
     // Add menus
     createMenus();
 
@@ -439,13 +450,27 @@ MainWindow::MainWindow(QWidget *parent) : QMainWindow(parent)
     // That will also trigger the action to hide/show it
     viewSidePanel->setChecked(settings.value("viewSidePanel", true).toBool());
 
-
     // Set the "view status bar" checkable menu to its saved state, which
     // will also trigger the action to hide/show it
     viewStatusBar->setChecked(settings.value("viewStatusBar", true).toBool());
 
     settings.endGroup();
 
+
+    // If User ID is defined, set PumpController in motion
+    if (!userID.isEmpty())
+    {
+        pumpController->setUserCredentials(this->userID);
+        // getUserProfile() will be called from setUserCredentials()
+    }
+    else // Otherwise, just say so in the statusbar
+    {
+        this->setStatusBarMessage(tr("Your account is not configured yet."));
+    }
+
+    this->adjustTimelineSizes();
+    qApp->processEvents();
+
     qDebug() << "MainWindow created";
 }
 
@@ -557,7 +582,7 @@ void MainWindow::createMenus()
     sessionUpdateMainTimeline = new QAction(QIcon::fromTheme("view-refresh"),
                                             tr("&Update Main Timeline"),
                                             this);
-    sessionUpdateMainTimeline->setShortcut(QKeySequence::Refresh);
+    sessionUpdateMainTimeline->setShortcut(QKeySequence(Qt::Key_F5));
     connect(sessionUpdateMainTimeline, SIGNAL(triggered()),
             mainTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateMainTimeline);
@@ -565,6 +590,7 @@ void MainWindow::createMenus()
     sessionUpdateDirectTimeline = new QAction(QIcon::fromTheme("view-refresh"),
                                               tr("Update &Messages Timeline"),
                                               this);
+    sessionUpdateDirectTimeline->setShortcut(QKeySequence(Qt::Key_F6));
     connect(sessionUpdateDirectTimeline, SIGNAL(triggered()),
             directTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateDirectTimeline);
@@ -572,6 +598,7 @@ void MainWindow::createMenus()
     sessionUpdateActivityTimeline = new QAction(QIcon::fromTheme("view-refresh"),
                                                 tr("Update &Activity Timeline"),
                                                 this);
+    sessionUpdateActivityTimeline->setShortcut(QKeySequence(Qt::Key_F7));
     connect(sessionUpdateActivityTimeline, SIGNAL(triggered()),
             activityTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateActivityTimeline);
@@ -580,6 +607,7 @@ void MainWindow::createMenus()
     sessionUpdateFavoritesTimeline = new QAction(QIcon::fromTheme("view-refresh"),
                                                  tr("Update Favorites &Timeline"),
                                                  this);
+    sessionUpdateFavoritesTimeline->setShortcut(QKeySequence(Qt::Key_F8));
     connect(sessionUpdateFavoritesTimeline, SIGNAL(triggered()),
             favoritesTimeline, SLOT(goToFirstPage()));
     sessionMenu->addAction(sessionUpdateFavoritesTimeline);
@@ -607,9 +635,9 @@ void MainWindow::createMenus()
     sessionMarkAllAsRead = new QAction(QIcon::fromTheme("mail-mark-read"),
                                        tr("Mark All as Read"),
                                        this);
-    // connect(...
-    sessionMarkAllAsRead->setDisabled(true); // TMPFIX: until implemented
-    sessionMarkAllAsRead->setVisible(false); // Same thing!
+    sessionMarkAllAsRead->setShortcut(QKeySequence("Ctrl+R"));
+    connect(sessionMarkAllAsRead, SIGNAL(triggered()),
+            this, SLOT(markAllAsRead()));
     sessionMenu->addAction(sessionMarkAllAsRead);    
 
     sessionMenu->addSeparator();
@@ -629,7 +657,7 @@ void MainWindow::createMenus()
 
     sessionQuit = new QAction(QIcon::fromTheme("application-exit"),
                               tr("&Quit"), this);
-    sessionQuit->setShortcut(QKeySequence::Quit);
+    sessionQuit->setShortcut(QKeySequence("Ctrl+Q"));
     connect(sessionQuit, SIGNAL(triggered()),
             this, SLOT(quitProgram()));
     sessionMenu->addAction(sessionQuit);
@@ -682,7 +710,6 @@ void MainWindow::createMenus()
             profileEditor, SLOT(show()));
     settingsMenu->addAction(settingsEditProfile);
 
-
     settingsAccount = new QAction(QIcon::fromTheme("dialog-password"),
                                   tr("&Account"), this);
     connect(settingsAccount, SIGNAL(triggered()),
@@ -691,6 +718,12 @@ void MainWindow::createMenus()
 
     settingsMenu->addSeparator();
 
+    settingsFilters = new QAction(QIcon::fromTheme("view-filter"),
+                                  tr("&Filters"), this);
+    connect(settingsFilters, SIGNAL(triggered()),
+            filterEditor, SLOT(show()));
+    settingsMenu->addAction(settingsFilters);
+
     settingsConfigure = new QAction(QIcon::fromTheme("configure"),
                                     tr("&Configure Dianara"), this);
     connect(settingsConfigure, SIGNAL(triggered()),
@@ -730,6 +763,8 @@ void MainWindow::createMenus()
 
     // Context menu for the tray icon
     trayContextMenu = new QMenu("Tray Context Menu");
+    trayContextMenu->setSeparatorsCollapsible(false);
+    trayContextMenu->addSeparator()->setText("Dianara");
     trayContextMenu->addAction(QIcon(":/icon/64x64/dianara.png"),
                                tr("&Show Window"),
                                this, SLOT(show()));
@@ -835,29 +870,35 @@ void MainWindow::adjustTimelineSizes()
     // FIXME: adding +4 pixels should not be hardcoded
 
     int timelineWidth;
+    int timelineHeight;
 
-    // Get the right timelinewidth based on currectly active tab's timeline width
+    // Get the right timelinewidth based on currently active tab's timeline width
     switch (this->tabWidget->currentIndex())
     {
     case 0: // main
         timelineWidth = mainTimelineScrollArea->width() - scrollbarWidth;
+        timelineHeight = mainTimelineScrollArea->height();
         mainTimeline->resizePosts();
         break;
     case 1: // direct
         timelineWidth = directTimelineScrollArea->width() - scrollbarWidth;
+        timelineHeight = directTimelineScrollArea->height();
         directTimeline->resizePosts();
         break;
     case 2: // activity
         timelineWidth = activityTimelineScrollArea->width() - scrollbarWidth;
+        timelineHeight = activityTimelineScrollArea->height();
         activityTimeline->resizePosts();
         break;
     case 3: // favorites
         timelineWidth = favoritesTimelineScrollArea->width() - scrollbarWidth;
+        timelineHeight = favoritesTimelineScrollArea->height();
         favoritesTimeline->resizePosts();
         break;
 
     default: // Contacts tab, ATM
         timelineWidth = contactList->width() - scrollbarWidth;
+        timelineHeight = contactList->height();
     }
 
     // Then set the maximum width for all of them based on that
@@ -865,6 +906,17 @@ void MainWindow::adjustTimelineSizes()
     directTimeline->setMaximumWidth(timelineWidth);
     activityTimeline->setMaximumWidth(timelineWidth);
     favoritesTimeline->setMaximumWidth(timelineWidth);
+
+
+    // Some basic 1:2 proportions TMP FIXME
+    if (timelineHeight > (timelineWidth * 2))
+    {
+        timelineHeight = timelineWidth * 2;
+    }
+    mainTimeline->setMinMaxHeightForPosts(timelineHeight);
+    directTimeline->setMinMaxHeightForPosts(timelineHeight);
+    activityTimeline->setMinMaxHeightForPosts(timelineHeight);
+    favoritesTimeline->setMinMaxHeightForPosts(timelineHeight);
 }
 
 
@@ -892,7 +944,7 @@ void MainWindow::loadSettings()
     // Main window state
     settings.beginGroup("MainWindow");
 
-    this->resize(settings.value("windowSize", QSize(640, 450)).toSize());
+    this->resize(settings.value("windowSize", QSize(680, 560)).toSize());
     if (!firstRun)
     {
         this->move(settings.value("windowPosition").toPoint());
@@ -910,8 +962,11 @@ void MainWindow::loadSettings()
 
     this->updateInterval = settings.value("updateInterval", 5).toInt();
 
-    this->postsPerPage = settings.value("postsPerPage", 20).toInt();
-    this->pumpController->setPostsPerPage(this->postsPerPage);
+    this->postsPerPageMain = settings.value("postsPerPageMain", 20).toInt();
+    this->pumpController->setPostsPerPageMain(this->postsPerPageMain);
+
+    this->postsPerPageOther = settings.value("postsPerPageOther", 5).toInt();
+    this->pumpController->setPostsPerPageOther(this->postsPerPageOther);
 
 
     this->tabsPosition = settings.value("tabsPosition", QTabWidget::North).toInt();
@@ -921,9 +976,6 @@ void MainWindow::loadSettings()
     tabWidget->setMovable(tabsMovable);
 
 
-    // publisherType 0 by default, buttons below
-    this->publisherType = settings.value("publisherType", 0).toInt();
-
     this->publicPosts = settings.value("publicPosts", false).toBool();
     this->publisher->setDefaultPublicPosting(this->publicPosts);
 
@@ -964,12 +1016,12 @@ void MainWindow::saveSettings()
 
     settings.setValue("updateInterval", this->updateInterval);
 
-    settings.setValue("postsPerPage", this->postsPerPage);
+    settings.setValue("postsPerPageMain",  this->postsPerPageMain);
+    settings.setValue("postsPerPageOther", this->postsPerPageOther);
 
     settings.setValue("tabsPosition", this->tabsPosition);
-    settings.setValue("tabsMovable", this->tabsMovable);
+    settings.setValue("tabsMovable",  this->tabsMovable);
 
-    settings.setValue("publisherType", this->publisherType);
     settings.setValue("publicPosts", this->publicPosts);
 
     settings.setValue("showNotifications", this->showNotifications);
@@ -1021,16 +1073,19 @@ void MainWindow::updateUserID(QString newUserID)
  * Update settings changed from ConfigDialog()
  *
  */
-void MainWindow::updateSettings(int newUpdateInterval, int newPostsPerPage,
-                                int newTabsPosition, bool newTabsMovable,
-                                int newPublisherType, bool newPublicPosts,
-                                int newShowNotifications)
+void MainWindow::updateSettings(int newUpdateInterval,
+                                int newPostsPerPageMain, int newPostsPerPageOther,
+                                int newTabsPosition,bool newTabsMovable,
+                                bool newPublicPosts, int newShowNotifications)
 {
     this->updateInterval = newUpdateInterval;
     this->updateTimer->setInterval(updateInterval * 1000 * 60);
 
-    this->postsPerPage = newPostsPerPage;
-    this->pumpController->setPostsPerPage(this->postsPerPage);
+    this->postsPerPageMain = newPostsPerPageMain;
+    this->pumpController->setPostsPerPageMain(this->postsPerPageMain);
+
+    this->postsPerPageOther = newPostsPerPageOther;
+    this->pumpController->setPostsPerPageOther(this->postsPerPageOther);
 
     this->tabsPosition = newTabsPosition;
     this->tabWidget->setTabPosition((QTabWidget::TabPosition)tabsPosition);
@@ -1038,8 +1093,6 @@ void MainWindow::updateSettings(int newUpdateInterval, int newPostsPerPage,
     this->tabsMovable = newTabsMovable;
     this->tabWidget->setMovable(tabsMovable);
 
-    this->publisherType = newPublisherType;
-
     this->publicPosts = newPublicPosts;
     this->publisher->setDefaultPublicPosting(this->publicPosts);
 
@@ -1048,9 +1101,9 @@ void MainWindow::updateSettings(int newUpdateInterval, int newPostsPerPage,
 
 
     qDebug() << "updateInterval updated:" << updateInterval << updateInterval*60000;
+    qDebug() << "postsPerPage Main/Other:" << postsPerPageMain << postsPerPageOther;
     qDebug() << "tabsPosition updated:" << tabsPosition << tabWidget->tabPosition();
     qDebug() << "tabsMovable updated:" << tabsMovable;
-    qDebug() << "publisherType updated:" << publisherType;
     qDebug() << "public posts updated:" << publicPosts;
     qDebug() << "Notifications updated:" << showNotifications;
 }
@@ -1114,8 +1167,9 @@ void MainWindow::showTrayFallbackMessage(QString message)
 
 
 
-void MainWindow::updateProfileData(QString avatarURL, QString fullName,
-                                   QString hometown, QString bio)
+void MainWindow::updateProfileData(QString avatarUrl, QString fullName,
+                                   QString hometown, QString bio,
+                                   QString eMail)
 {
     if (!bio.isEmpty())
     {
@@ -1130,7 +1184,7 @@ void MainWindow::updateProfileData(QString avatarURL, QString fullName,
     this->userHometownLabel->setToolTip(bio);
     qDebug() << "Updated profile data from server:" << fullName << " @" << hometown;
 
-    this->avatarURL = avatarURL;
+    this->avatarURL = avatarUrl;
     qDebug() << "Own avatar URL:" << avatarURL;
 
 
@@ -1156,7 +1210,8 @@ void MainWindow::updateProfileData(QString avatarURL, QString fullName,
 
     // Fill/update this info in the profile editor too
     this->profileEditor->setProfileData(avatarURL, fullName,
-                                        hometown, bio);
+                                        hometown, bio,
+                                        eMail);
 }
 
 
@@ -1210,7 +1265,7 @@ void MainWindow::scrollMainTimelineToTop()
     this->mainTimelineScrollArea->verticalScrollBar()->setValue(0);
     this->mainTimelineScrollArea->horizontalScrollBar()->setValue(0);
 
-    this->adjustTimelineSizes(); // kinda TMP
+    this->adjustTimelineSizes();
 }
 
 void MainWindow::scrollDirectTimelineToTop()
@@ -1400,32 +1455,43 @@ void MainWindow::setTitleAndTrayInfo(int currentTab)
 }
 
 
+/*
+ * Set the title for the minor feed (Meanwhile), with new item count
+ *
+ */
+void MainWindow::setMinorFeedTitle(int newItemsCount)
+{
+    QString title = tr("Meanwhile...");
+    if (newItemsCount > 0)
+    {
+        title.append(QString(" (%1)").arg(newItemsCount));
+    }
+
+
+    this->leftPanel->setItemText(0, title);
+}
+
+
 
 
 /*
  * Store avatars on disk
  *
  */
-void MainWindow::storeAvatar(QByteArray avatarData, QUrl avatarURL)
+void MainWindow::storeAvatar(QByteArray avatarData, QUrl avatarUrl)
 {
-    QString avatarString = avatarURL.toString();
-    QString fileName = avatarString.toUtf8().toBase64();
-
-
-    QString fileExtension = avatarString.remove(QRegExp(".*\\."));
-    fileName.append("." + fileExtension);
-
+    QString fileName = MiscHelpers::getCachedAvatarFilename(avatarUrl.toString());
     qDebug() << "Saving avatar to disk: " << fileName;
 
-    QFile avatarFile(dataDirectory + "/avatars/" + fileName);
+    QFile avatarFile(fileName);
     avatarFile.open(QFile::WriteOnly);
     avatarFile.write(avatarData);
     avatarFile.close();
 
-    this->pumpController->notifyAvatarStored(avatarURL.toString(),
+    this->pumpController->notifyAvatarStored(avatarUrl.toString(),
                                              avatarFile.fileName());
 
-    if (avatarURL == this->avatarURL)
+    if (avatarUrl == this->avatarURL)
     {
         this->avatarIconButton->setIcon(QIcon(QPixmap(avatarFile.fileName())
                                               .scaled(64, 64,
@@ -1444,19 +1510,17 @@ void MainWindow::storeAvatar(QByteArray avatarData, QUrl avatarURL)
  * Store images on disk
  *
  */
-void MainWindow::storeImage(QByteArray imageData, QUrl imageURL)
+void MainWindow::storeImage(QByteArray imageData, QUrl imageUrl)
 {
-    QString imageString = imageURL.toString();
-
-    QString fileName = imageString.toUtf8().toBase64();
+    QString fileName = MiscHelpers::getCachedImageFilename(imageUrl.toString());
     qDebug() << "Saving image to disk: " << fileName;
 
-    QFile imageFile(dataDirectory + "/images/" + fileName);
+    QFile imageFile(fileName);
     imageFile.open(QFile::WriteOnly);
     imageFile.write(imageData);
     imageFile.close();
 
-    this->pumpController->notifyImageStored(imageURL.toString());
+    this->pumpController->notifyImageStored(imageUrl.toString());
 
     qDebug() << "imageData size:" << imageData.size();
 }
@@ -1473,6 +1537,23 @@ void MainWindow::setStatusBarMessage(QString message)
 }
 
 
+/*
+ * Mark all posts in all timelines as read
+ * and clear their counters
+ *
+ */
+void MainWindow::markAllAsRead()
+{
+    mainTimeline->markPostsAsRead();
+    directTimeline->markPostsAsRead();
+    activityTimeline->markPostsAsRead();
+    favoritesTimeline->markPostsAsRead();
+
+    meanwhileFeed->markAllAsRead();
+    this->setMinorFeedTitle(0);
+}
+
+
 
 /*
  * Hide or show the side panel
@@ -1491,11 +1572,12 @@ void MainWindow::toggleSidePanel(bool shown)
     qDebug() << "Showing side panel:" << shown;
     this->leftSideWidget->setVisible(shown);
 
-    /*if (!shown)
+
+    if (!shown)
     {
+        qApp->processEvents();
         this->adjustTimelineSizes();
     }
-    */
 }
 
 
@@ -1561,8 +1643,8 @@ void MainWindow::visitFAQ()
 void MainWindow::aboutDianara()
 {
     QMessageBox::about(this, tr("About Dianara"),
-                       "<b>Dianara v1.0</b><br>"
-                       "Copyright 2012-2013  JanKusanagi<br><br>"
+                       "<b>Dianara v1.1</b><br>"
+                       "Copyright 2012-2014  JanKusanagi<br><br>"
                        "<a href=\"http://jancoding.wordpress.com/dianara\">"
                        "http://jancoding.wordpress.com/dianara</a><br><br>"
 
