@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -62,6 +62,7 @@
 #include "contactlist.h"
 #include "minorfeed.h"
 #include "profileeditor.h"
+#include "filtereditor.h"
 
 
 class MainWindow : public QMainWindow
@@ -87,18 +88,19 @@ public:
 public slots:
     void updateUserID(QString newUserID);
     void updateSettings(int newUpdateInterval,
-                        int newPostsPerPage,
+                        int newPostsPerPageMain,
+                        int newPostsPerPageOther,
                         int newTabsPosition,
                         bool newTabsMovable,
-                        int newPublisherType,
                         bool newPublicPosts,
                         int newShowNotifications);
 
     void trayControl(QSystemTrayIcon::ActivationReason reason);
     void showTrayFallbackMessage(QString message);
 
-    void updateProfileData(QString avatarURL, QString fullName,
-                           QString hometown, QString bio);
+    void updateProfileData(QString avatarUrl, QString fullName,
+                           QString hometown, QString bio,
+                           QString eMail);
 
     void updateAllTimelines();
     void updateMainDirectMinorTimelines();
@@ -118,12 +120,14 @@ public slots:
     void setTimelineTabTitle(int timelineType, int newPostCount);
 
     void setTitleAndTrayInfo(int currentTab);
+    void setMinorFeedTitle(int newItemsCount);
 
-    void storeAvatar(QByteArray avatarData, QUrl avatarURL);
-    void storeImage(QByteArray imageData, QUrl imageURL);
+    void storeAvatar(QByteArray avatarData, QUrl avatarUrl);
+    void storeImage(QByteArray imageData, QUrl imageUrl);
 
     void setStatusBarMessage(QString message);
 
+    void markAllAsRead();
 
     void toggleSidePanel(bool shown);
     void toggleStatusBar(bool shown);
@@ -143,7 +147,7 @@ protected:
 
 
 private:
-    // Menus
+    ////////////////////////////////////// Menus
     QMenu *sessionMenu;
     QMenu *viewMenu;
     QMenu *settingsMenu;
@@ -167,17 +171,19 @@ private:
 
     QAction *settingsEditProfile;
     QAction *settingsAccount;
+    QAction *settingsFilters;
     QAction *settingsConfigure;
 
     QAction *helpVisitWebsite;
     QAction *helpVisitPumpFAQ;
     QAction *helpAbout;
-
+    ////////////////////////////////////// End menus
 
     QSplitter *mainSplitter;
 
     QWidget *leftSideWidget;
     QVBoxLayout *leftLayout;
+    QVBoxLayout *userInfoLayout;
     QToolBox *leftPanel;
 
     QWidget *rightSideWidget;
@@ -201,15 +207,17 @@ private:
     AccountDialog *accountDialog;
     ProfileEditor *profileEditor;
     ConfigDialog *configDialog;
+    FilterEditor *filterEditor;
     PumpController *pumpController;
     FDNotifications *fdNotifier;
 
     MinorFeed *meanwhileFeed;
 
-    int postsPerPage;
+    int postsPerPageMain;
     TimeLine *mainTimeline;
     QScrollArea *mainTimelineScrollArea;
 
+    int postsPerPageOther;
     TimeLine *directTimeline;
     QScrollArea *directTimelineScrollArea;
 
@@ -223,7 +231,6 @@ private:
     ContactList *contactList;
 
     Publisher *publisher;
-    int publisherType;
 
 
     bool firstRun;
