@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -26,12 +26,14 @@
 #include <QLabel>
 #include <QFont>
 #include <QVariantList>
+#include <QPushButton>
 
 #include <QDebug>
 
 #include "pumpcontroller.h"
 #include "mischelpers.h"
 #include "minorfeeditem.h"
+#include "asactivity.h"
 
 
 class MinorFeed : public QFrame
@@ -43,19 +45,31 @@ public:
                        QWidget *parent = 0);
     ~MinorFeed();
     void clearContents();
+    void markAllAsRead();
 
 signals:
-
+    void newItemsCountChanged(int count);
     
 public slots:
     void updateFeed();
+    void getMoreActivities();
     void setFeedContents(QVariantList activitiesList);
 
+    void decreaseNewItemsCount();
+
 
 private:
+    int feedOffset;
+
+    QString previousNewestActivityId;
     QList<MinorFeedItem *> itemsInFeed;
 
+    int newItemsCount;
+
     QVBoxLayout *mainLayout;
+    QVBoxLayout *itemsLayout;
+    QPushButton *getMoreButton;
+
     PumpController *pController;
 };
 
