@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -27,10 +27,14 @@
 #include <QLabel>
 #include <QIcon>
 #include <QFile>
+#include <QPushButton>
 
 #include <QDebug>
 
+#include "pumpcontroller.h"
 #include "timestamp.h"
+#include "asactivity.h"
+#include "post.h"
 
 
 class MinorFeedItem : public QFrame
@@ -38,27 +42,42 @@ class MinorFeedItem : public QFrame
     Q_OBJECT
 
 public:
-    explicit MinorFeedItem(QString timestamp,
-                           QString generator,
-                           QString activityDescription,
-                           QString activityActorAvatar,
-                           QString activityObjectAuthor,
-                           QString activityObjectContent,
+    explicit MinorFeedItem(ASActivity *activity,
+                           QString activityActorAvatarFilename,
+                           PumpController *pumpController,
                            QWidget *parent = 0);
     ~MinorFeedItem();
+
+    void setItemAsNew(bool isNew);
+
     
 signals:
+    void itemRead();
+
     
 public slots:
+    void openOriginalPost();
 
+protected:
+    virtual void mousePressEvent(QMouseEvent *event);
 
 private:
+    PumpController *pController;
+
     QHBoxLayout *mainLayout;
+    QVBoxLayout *leftLayout;
     QVBoxLayout *rightLayout;
 
     QLabel *avatarLabel;
     QLabel *timestampLabel;
     QLabel *activityDescriptionLabel;
+
+    QPushButton *openButton;
+
+    QVariantMap originalObjectMap;
+    QVariantMap inReplyToMap;
+
+    bool itemIsNew;
 };
 
 #endif // MINORFEEDITEM_H
