@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -29,19 +29,23 @@ MiscHelpers::MiscHelpers(QObject *parent) : QObject(parent)
 QString MiscHelpers::getCachedAvatarFilename(QString url)
 {
     QString localFilename;
+
+    if (!url.isEmpty())
+    {
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+        localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
 #else
-    localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
+        localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
 #endif
-    localFilename.append("/avatars/");
-    localFilename.append(url.trimmed().toUtf8().toBase64());
+        localFilename.append("/avatars/");
+        localFilename.append(url.trimmed().toUtf8().toBase64());
 
-    QString fileExtension = url;
-    fileExtension.remove(QRegExp(".*\\.")); // remove all but the extension
+        QString fileExtension = url;
+        fileExtension.remove(QRegExp(".*\\.")); // remove all but the extension
 
-    localFilename.append(".");
-    localFilename.append(fileExtension);
+        localFilename.append(".");
+        localFilename.append(fileExtension);
+    }
 
     return localFilename;
 }
@@ -55,14 +59,31 @@ QString MiscHelpers::getCachedAvatarFilename(QString url)
 QString MiscHelpers::getCachedImageFilename(QString url)
 {
     QString localFilename;
-#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
-    localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
-#else
-    localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
-#endif
-    localFilename.append("/images/");
-    localFilename.append(url.trimmed().toUtf8().toBase64());
 
+    if (!url.isEmpty())
+    {
+        url = url.trimmed();
+        if (url.startsWith("http://"))
+        {
+            url.remove(0, 7); // remove http://
+        }
+        if (url.startsWith("https://"))
+        {
+            url.remove(0, 8); // remove https://
+        }
+
+        QByteArray base64url = url.toUtf8().toBase64();
+        base64url.truncate(255); // Limit filename lenght! Just in case the URL is VERY long
+
+
+#if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
+        localFilename = QDesktopServices::storageLocation(QDesktopServices::DataLocation);
+#else
+        localFilename = QStandardPaths::standardLocations(QStandardPaths::DataLocation).first();
+#endif
+        localFilename.append("/images/");
+        localFilename.append(base64url);
+    }
 
     return localFilename;
 }
@@ -101,6 +122,19 @@ int MiscHelpers::getImageWidth(QString fileURI)
 }
 
 
+QString MiscHelpers::fixLongName(QString name)
+{
+    // very TMP optimization of LOOONG names / FIXME
+    if (name.length() > 16)
+    {
+        name.replace("@", "@ ");
+        name.replace(".", ". ");
+    }
+
+    return name;
+}
+
+
 
 /*
  * Return a pretty string with the size of a file, like
@@ -143,6 +177,7 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
     // if no <img tag is found, just return the original HTML
     if (!originalHtml.contains("<img"))
     {
+        //qDebug() << "MiscHelpers::htmlWithReplacedImages(); HTML does NOT contain <img> tags...";
         return QStringList(originalHtml);
     }
 
@@ -152,10 +187,10 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
     QStringList imageList;
     QString imgSrc;
 
-    QRegExp regExp("\\<img(.+)src=\"([^\"]+)\"(.*)\\>");
+    QRegExp regExp("\\<img(.+)src=(\"|\\')([^\"\\']+)(\"|\\')(.*)\\>");
     regExp.setMinimal(true);
 
-    int matchedLength;
+    int matchedLength = 0;
     int stringPos = 0;
     while (matchedLength != -1)
     {
@@ -164,10 +199,12 @@ QStringList MiscHelpers::htmlWithReplacedImages(QString originalHtml, int postWi
 
 
         //qDebug() << "regExp match = " << regExp.cap(0);
-        //qDebug() << "Groups:" << regExp.cap(1) << " // " << regExp.cap(2) << " // " << regExp.cap(3);
+        //qDebug() << "Groups:" << regExp.cap(1) << " // " << regExp.cap(2)
+        //         << " // " << regExp.cap(3) << " // " << regExp.cap(4)
+        //         << " // " << regExp.cap(5);
         //qDebug() << "Matched length is:" << matchedLength;
 
-        imgSrc = regExp.cap(2);
+        imgSrc = regExp.cap(3);
         if (!imgSrc.isEmpty()) // if not an empty string, add to the list, and replace HTML
         {
             imageList.append(imgSrc);
@@ -205,13 +242,15 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
 {
     QString cleanHtml = originalHtml;
 
-
     cleanHtml.replace("\n", " ");  // Remove line breaks, as that results in server error 500
 
 
+    QRegExp doctypeRE("<!DOCTYPE.*>");
+    doctypeRE.setMinimal(true);
+    cleanHtml.remove(doctypeRE);
+
     QRegExp headRE("<html><head>.*</head>");
     headRE.setMinimal(true);
-
     cleanHtml.remove(headRE);
     cleanHtml.remove("</body></html>");
 
@@ -220,7 +259,7 @@ QString MiscHelpers::cleanupHtml(QString originalHtml)
 
     cleanHtml.remove(bodyRE);
 
-    return cleanHtml;
+    return cleanHtml.trimmed();
 }
 
 
