@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -50,6 +50,8 @@ public:
     static QString getImageContentType(QString fileURI);
     static int getImageWidth(QString fileURI);
 
+    static QString fixLongName(QString name);
+
     static QString fileSizeString(QString fileURI);
 
     static QStringList htmlWithReplacedImages(QString originalHtml, int postWidth);
@@ -57,10 +59,6 @@ public:
 
     static QString quotedText(QString author, QString content);
 
-signals:
-
-public slots:
-
 };
 
 #endif // MISCHELPERS_H
