@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,13 +21,14 @@
 #include "post.h"
 
 Post::Post(PumpController *pumpController,
-           QMap<QString,QString> postData,
-           QVariantList lastLikesVariantList,
-           QVariantList lastCommentsVariantList,
-           QVariantList lastSharesVariantList,
+           ASActivity *activity,
+           bool isStandalone,
            QWidget *parent)  :  QFrame(parent)
 {
     this->pController = pumpController;
+    this->standalone = isStandalone;
+
+    activity->setParent(this); // reparent the passed activity
 
     this->setSizePolicy(QSizePolicy::MinimumExpanding,
                         QSizePolicy::Minimum);
@@ -36,26 +37,51 @@ Post::Post(PumpController *pumpController,
     leftColumnLayout = new QVBoxLayout();
 
 
-    this->postID = postData.value("id");
-    this->postType = postData.value("postType");
-    this->postURL = postData.value("url");
-    this->postAuthorID = postData.value("authorId");
-    this->postAuthorName = postData.value("author");
+    this->postId = activity->object()->getId();
+    this->postType = activity->object()->getType();
+    this->postUrl = activity->object()->getUrl();
+    this->postAuthorId = activity->getAuthorId();
+    this->postAuthorName = activity->getAuthorName();
     if (postAuthorName.isEmpty()) // In case name is empty, use webfinger ID
     {
-        postAuthorName = this->postAuthorID;
+        postAuthorName = this->postAuthorId;
     }
-    this->postAuthorURL = postData.value("authorUrl");
+    this->postAuthorUrl = activity->getAuthorUrl();
 
     // Save post title for openClickedURL(), etc
-    this->postTitle = postData.value("title");
+    this->postTitle = activity->object()->getTitle();
 
+    QString generator = activity->getGenerator();
+
+    // If standalone post, set window title
+    if (standalone)
+    {
+        QString postTypeString;
+        if (postType == "note")
+        {
+            postTypeString = tr("Note");
+        }
+        else if (postType == "image")
+        {
+            postTypeString = tr("Image");
+        }
+        else if (postType == "comment")
+        {
+            postTypeString = tr("Comment");
+        }
+        else
+        {
+            postTypeString = tr("Other",
+                                "As in: other type of post");
+        }
+
+        QString windowTitle = tr("Post", "Noun, not verb")
+                              + ": " + postTypeString + " - Dianara";
+        this->setWindowTitle(windowTitle);
+    }
 
     postIsUnread = false;
-    if (postData.value("postIsNew") == "true")
-    {
-        this->postIsUnread = true;
-    }
+
 
     QFont detailsFont;
     detailsFont.setPointSize(detailsFont.pointSize() - 2); // FIXME: check size first
@@ -65,16 +91,13 @@ Post::Post(PumpController *pumpController,
 
     // Is the post a reshare? Indicate who shared it
     postIsSharedLabel = new QLabel();
-    if (postData.value("postIsShared") == "true")
+    if (activity->isShared())
     {
-        QString sharedBy = postData.value("sharedBy");
-        if (sharedBy.length() > 16)   // very TMP optimization of LOOONG names / FIXME
-        {
-            sharedBy.replace("@", "@ ");
-            sharedBy.replace(".", ". ");
-        }
+        this->postSharedById = activity->getSharedById();
+
+        QString sharedByName = MiscHelpers::fixLongName(activity->getSharedByName());
         postIsSharedLabel->setText(QString::fromUtf8("\342\231\272  ") // Recycling symbol
-                                   + tr("Via %1").arg(sharedBy));
+                                   + tr("Via %1").arg(sharedByName));
         postIsSharedLabel->setWordWrap(true);
         postIsSharedLabel->setAlignment(Qt::AlignCenter);
         postIsSharedLabel->setFont(detailsFont);
@@ -82,28 +105,47 @@ Post::Post(PumpController *pumpController,
         postIsSharedLabel->setBackgroundRole(QPalette::Base);
         postIsSharedLabel->setAutoFillBackground(true);
         postIsSharedLabel->setFrameStyle(QFrame::Panel | QFrame::Raised);
-        postIsSharedLabel->setToolTip(postData.value("sharedById"));
+
+        QString sharedByAvatarFilename = MiscHelpers::getCachedAvatarFilename(activity->getSharedByAvatar());
+        QString sharedByTooltipString = "<img align=\"left\" src=\""
+                                        + sharedByAvatarFilename
+                                        + "\" width=\"48\" />";
+        sharedByTooltipString.append("&nbsp;&nbsp;<b>" + activity->getSharedByName() + "</b><br>");
+        sharedByTooltipString.append("&nbsp;&nbsp;<i>" + this->postSharedById + "</i>");
+        QString exactShareTime = Timestamp::localTimeDate(activity->getUpdatedAt());
+        QString fuzzyShareTime = Timestamp::fuzzyTime(activity->getUpdatedAt());
+        sharedByTooltipString.append("<br><hr><br>"
+                                     + tr("Shared on %1").arg(exactShareTime)
+                                     + QString("<br>(%1)").arg(fuzzyShareTime));
+        if (!generator.isEmpty())
+        {
+            sharedByTooltipString.append(" " + tr("using %1").arg(generator));
+            generator.clear(); // So it's not used in the post timestamp tooltip!
+        }
+        postIsSharedLabel->setToolTip(sharedByTooltipString);
         leftColumnLayout->addWidget(postIsSharedLabel);
     }
     leftColumnLayout->addSpacing(2);
 
 
-    QString authorTooltipInfo = "<b>" + postAuthorID + "</b>";
+    QString authorTooltipInfo = "<b>" + this->postAuthorName + "</b><br>";
+    authorTooltipInfo.append("<b><i>" + postAuthorId + "</i></b>");
     authorTooltipInfo.append("<br>");
-    if (!postData.value("authorHometown").isEmpty())
+    if (!activity->getAuthorHometown().isEmpty())
     {
         authorTooltipInfo.append("<br>");
-        authorTooltipInfo.append("<b>" + tr("Hometown") + "</b>: " + postData.value("authorHometown"));
+        authorTooltipInfo.append("<b>" + tr("Hometown") + "</b>: "
+                                 + activity->getAuthorHometown());
         authorTooltipInfo.append("<br>");
     }
-    if (!postData.value("authorBio").isEmpty())
+    if (!activity->getAuthorBio().isEmpty())
     {
         authorTooltipInfo.append("<br>");
-        authorTooltipInfo.append(postData.value("authorBio"));
+        authorTooltipInfo.append(activity->getAuthorBio());
     }
     authorTooltipInfo.replace("\n", "<br>"); // HTML newlines
 
-    if (this->postAuthorID == pController->currentUserID())
+    if (this->postAuthorId == pController->currentUserId())
     {
         postIsOwn = true;
         qDebug() << "post is our own!";
@@ -125,16 +167,16 @@ Post::Post(PumpController *pumpController,
     postAuthorAvatarButton->setToolTip(authorTooltipInfo);
 
     // Get "following" status before creating avatar menu
-    this->postAuthorFollowed = this->pController->userInFollowing(this->postAuthorID);
+    this->postAuthorFollowed = this->pController->userInFollowing(this->postAuthorId);
     this->createAvatarMenu();
     postAuthorAvatarButton->setMenu(avatarMenu);
 
-    this->postAuthorAvatarUrl = postData.value("authorAvatar");
+    this->postAuthorAvatarUrl = activity->getAuthorAvatar();
 
     // Get local file name for avatar, which is stored in base64 hash form
     QString avatarFilename = MiscHelpers::getCachedAvatarFilename(postAuthorAvatarUrl);
 
-    if (QFile::exists(avatarFilename) && !postAuthorAvatarUrl.isEmpty())
+    if (QFile::exists(avatarFilename))
     {
         // Load avatar if already cached
         postAuthorAvatarButton->setIcon(QIcon(QPixmap(avatarFilename).scaled(48, 48,
@@ -167,12 +209,7 @@ Post::Post(PumpController *pumpController,
     }
 
     // Author name
-    QString authorName = this->postAuthorName;
-    if (authorName.length() > 16)   // very TMP optimization of LOOONG names / FIXME
-    {
-        authorName.replace("@", "@ ");
-        authorName.replace(".", ". ");
-    }
+    QString authorName = MiscHelpers::fixLongName(this->postAuthorName);
     postAuthorNameLabel = new QLabel(authorName);
     postAuthorNameLabel->setTextFormat(Qt::PlainText);
     postAuthorNameLabel->setWordWrap(true);
@@ -185,9 +222,9 @@ Post::Post(PumpController *pumpController,
 
 
     // Post creation time
-    QString createdAt = postData["createdAt"];
+    QString createdAt = activity->object()->getCreatedAt();
     // and update time
-    QString updatedAt = postData["updatedAt"];
+    QString updatedAt = activity->object()->getUpdatedAt();
     if (updatedAt == createdAt)
     {
         updatedAt.clear();
@@ -196,26 +233,28 @@ Post::Post(PumpController *pumpController,
     // as specified in ISO 8601 http://en.wikipedia.org/wiki/ISO_8601
     QString exactPostTime = Timestamp::localTimeDate(createdAt);
     createdAt = Timestamp::fuzzyTime(createdAt);
+
+    QString dateGeneratorTooltip = tr("Posted on %1",
+                                      "1=Date").arg(exactPostTime);
+    if (!generator.isEmpty())
+    {
+        dateGeneratorTooltip.append("\n" +
+                                    tr("using %1",
+                                       "1=Program used for posting").arg(generator));
+    }
     if (!updatedAt.isEmpty())
     {
-        createdAt.append("\n");
-        createdAt.append(tr("Edited: %1").arg(Timestamp::fuzzyTime(updatedAt)));
+        // Using \n instead of <br> because I don't want this tooltip to be HTML (wrapped)
+        createdAt.append("\n"
+                         + tr("Edited: %1")
+                           .arg(Timestamp::fuzzyTime(updatedAt)));
+        dateGeneratorTooltip.append("\n\n"
+                                    + tr("Edited on %1")
+                                      .arg(Timestamp::localTimeDate(updatedAt)));
     }
 
-    QString generator = postData.value("generator");
-
     postCreatedAtLabel = new QLabel(createdAt);
-    if (generator.isEmpty())
-    {
-        postCreatedAtLabel->setToolTip(tr("Posted on %1","1=Date")
-                                  .arg(exactPostTime));
-    }
-    else
-    {
-        postCreatedAtLabel->setToolTip(tr("Posted on %1\n"
-                                     "using %2",        "1=Date of post, 2=Program used for posting")
-                                  .arg(exactPostTime).arg(generator));
-    }
+    postCreatedAtLabel->setToolTip(dateGeneratorTooltip);
     postCreatedAtLabel->setTextFormat(Qt::PlainText);
     postCreatedAtLabel->setWordWrap(true);
     postCreatedAtLabel->setAlignment(Qt::AlignLeft | Qt::AlignTop);
@@ -223,21 +262,31 @@ Post::Post(PumpController *pumpController,
     leftColumnLayout->addWidget(postCreatedAtLabel);
     leftColumnLayout->addSpacing(4);
 
+    // Location information, if any
+    QString location = activity->object()->getLocation();
+    postLocationLabel = new QLabel(tr("In") + ": <b>" + location + "</b>");
+    postLocationLabel->setWordWrap(true);
+    postLocationLabel->setFont(detailsFont);
+    if (!location.isEmpty())
+    {
+        leftColumnLayout->addWidget(postLocationLabel);
+        leftColumnLayout->addSpacing(2);
+    }
 
-    postToLabel = new QLabel(tr("To") + ": " + postData.value("to"));
+    postToLabel = new QLabel(tr("To") + ": " + activity->getToString());
     postToLabel->setWordWrap(true);
     postToLabel->setFont(detailsFont);
     postToLabel->setOpenExternalLinks(true);
-    if (!postData["to"].isEmpty())
+    if (!activity->getToString().isEmpty())
     {
         leftColumnLayout->addWidget(postToLabel);
     }
 
-    postCCLabel = new QLabel(tr("CC") + ": " + postData.value("cc"));
+    postCCLabel = new QLabel(tr("CC") + ": " + activity->getCCString());
     postCCLabel->setWordWrap(true);
     postCCLabel->setFont(detailsFont);
     postCCLabel->setOpenExternalLinks(true);
-    if (!postData["cc"].isEmpty())
+    if (!activity->getCCString().isEmpty())
     {
         leftColumnLayout->addWidget(postCCLabel);
     }
@@ -245,12 +294,13 @@ Post::Post(PumpController *pumpController,
     leftColumnLayout->addSpacing(4);
 
 
-    this->postLikesURL = postData.value("likesURL");
-    this->postCommentsURL = postData.value("commentsURL");
+    this->postLikesUrl = activity->object()->getLikesUrl();
+    this->postCommentsUrl = activity->object()->getCommentsUrl();
+    this->postSharesUrl = activity->object()->getSharesUrl();
 
 
     // Set this QLabels with parent=this, since we're gonna hide them right away
-    // They'll be reparented to the layout, but now having a parent before that
+    // They'll be reparented to the layout, but not having a parent before that
     // would cause visual glitches
     postLikesCountLabel = new QLabel(this);
     postLikesCountLabel->setWordWrap(true);
@@ -258,7 +308,7 @@ Post::Post(PumpController *pumpController,
     postLikesCountLabel->setFont(detailsFont);
     leftColumnLayout->addWidget(postLikesCountLabel);
     postLikesCountLabel->hide();
-    int likesCount = postData.value("likesCount").toInt();
+    int likesCount = activity->object()->getLikesCount().toInt();
     this->setLikesLabel(likesCount);
 
 
@@ -268,7 +318,7 @@ Post::Post(PumpController *pumpController,
     postCommentsCountLabel->setFont(detailsFont);
     leftColumnLayout->addWidget(postCommentsCountLabel);
     postCommentsCountLabel->hide();
-    int commentsCount = postData.value("commentsCount").toInt();
+    int commentsCount = activity->object()->getCommentsCount().toInt();
     this->setCommentsLabel(commentsCount);
 
 
@@ -278,7 +328,7 @@ Post::Post(PumpController *pumpController,
     postResharesCountLabel->setFont(detailsFont);
     leftColumnLayout->addWidget(postResharesCountLabel);
     postResharesCountLabel->hide();
-    int sharesCount = postData.value("resharesCount").toInt();
+    int sharesCount = activity->object()->getSharesCount().toInt();
     this->setSharesLabel(sharesCount);
 
 
@@ -294,7 +344,7 @@ Post::Post(PumpController *pumpController,
     //////////////////////////////////////////////////// Right column, content
 
     rightColumnLayout = new QVBoxLayout();
-    rightColumnLayout->setAlignment(Qt::AlignRight | Qt::AlignTop);
+    rightColumnLayout->setAlignment(Qt::AlignTop);
 
     ///////////////////////////////////// Title
     this->postTitleLabel = new QLabel();
@@ -342,7 +392,7 @@ Post::Post(PumpController *pumpController,
     // Like, comment, share buttons
     likeButton = new QPushButton(QIcon::fromTheme("emblem-favorite"), "like");
     likeButton->setCheckable(true);
-    this->fixLikeButton(postData.value("postIsLiked"));
+    this->fixLikeButton(activity->object()->isLiked());
     likeButton->setFlat(true);
     likeButton->setFont(buttonsFont);
     connect(likeButton, SIGNAL(clicked(bool)),
@@ -356,20 +406,32 @@ Post::Post(PumpController *pumpController,
     connect(commentButton, SIGNAL(clicked()),
             this, SLOT(commentOnPost()));
 
-    // Note: Gwenview includes 'document-share'
-    shareButton = new QPushButton(QIcon::fromTheme("mail-forward"),
-                                  tr("Share"));
-    shareButton->setToolTip(tr("Share this post"));
+    // Note: Gwenview includes 'document-share' icon
+    shareButton = new QPushButton(QIcon::fromTheme("mail-forward"), "*share*");
     shareButton->setFlat(true);
     shareButton->setFont(buttonsFont);
-    connect(shareButton, SIGNAL(clicked()),
-            this, SLOT(sharePost()));
+    if (postSharedById.isEmpty()
+        || (pController->currentUserId() != this->postSharedById))
+    {
+        shareButton->setText(tr("Share"));
+        shareButton->setToolTip(tr("Share this post"));
+        connect(shareButton, SIGNAL(clicked()),
+                this, SLOT(sharePost()));
+    }
+    else // Shared by us!
+    {
+        shareButton->setText(tr("Unshare"));
+        shareButton->setToolTip(tr("Unshare this post"));
+        connect(shareButton, SIGNAL(clicked()),
+                this, SLOT(unsharePost()));
+        shareButton->setDisabled(true); // FIXME: disabled for 1.1, since doesn't really work
+    }
 
 
 
     // Add like, comment, share and, if post is our own, edit and delete buttons
     buttonsLayout = new QHBoxLayout();
-    buttonsLayout->setAlignment(Qt::AlignHCenter | Qt::AlignBottom);
+    buttonsLayout->setAlignment(Qt::AlignHCenter | Qt::AlignTop);
     buttonsLayout->setContentsMargins(0, 0, 0, 0);
     buttonsLayout->setMargin(0);
     buttonsLayout->setSpacing(0);
@@ -408,12 +470,12 @@ Post::Post(PumpController *pumpController,
     // Get URL of post image, if it's "image" type of post
     if (this->postType == "image")
     {
-        postImageURL = postData.value("image");
+        postImageUrl = activity->object()->getImageUrl();
 
-        this->enqueueImageForDownload(postImageURL);
+        this->enqueueImageForDownload(postImageUrl);
     }
 
-    this->postOriginalText = postData.value("text"); // Save it for later...
+    this->postOriginalText = activity->object()->getContent(); // Save it for later...
     QStringList postTextImageList = MiscHelpers::htmlWithReplacedImages(postOriginalText,
                                                                         this->postText->width());
     postTextImageList.removeFirst(); // First is the HTML itself
@@ -445,17 +507,18 @@ Post::Post(PumpController *pumpController,
 
     if (!this->postTitle.isEmpty())
     {
-        rightColumnLayout->addWidget(postTitleLabel);
+        rightColumnLayout->addWidget(postTitleLabel, 0);
     }
-    rightColumnLayout->addWidget(postText,      2);
+    rightColumnLayout->addWidget(postText,      3);
     rightColumnLayout->addLayout(buttonsLayout, 0);
-    rightColumnLayout->addWidget(commenter,     1);
+    rightColumnLayout->addWidget(commenter,     0);
+    rightColumnLayout->addStretch(0);
 
 
     // Set the initial likes, comments and shares (4 most recent)
-    this->setLikes(lastLikesVariantList, likesCount);
-    this->commenter->setComments(lastCommentsVariantList);
-    this->setShares(lastSharesVariantList, sharesCount);
+    this->setLikes(activity->object()->getLastLikesList(), likesCount);
+    this->commenter->setComments(activity->object()->getLastCommentsList());
+    this->setShares(activity->object()->getLastSharesList(), sharesCount);
 
 
     mainLayout = new QHBoxLayout();
@@ -466,17 +529,20 @@ Post::Post(PumpController *pumpController,
     this->setLayout(mainLayout);
 
 
+
+    this->minMaxHeight = 400; // Initialize, but it'll be set before it's used anyway
+
     // Set read status
     this->setPostUnreadStatus();
 
-    qDebug() << "Post created" << this->postURL;
+    qDebug() << "Post created" << this->postUrl;
 }
 
 
 
 Post::~Post()
 {
-    qDebug() << "Post destroyed" << this->postURL;
+    qDebug() << "Post destroyed" << this->postUrl;
 }
 
 
@@ -487,12 +553,12 @@ Post::~Post()
 void Post::createAvatarMenu()
 {
     this->avatarMenu = new QMenu();
+    avatarMenu->setSeparatorsCollapsible(false);
 
     this->avatarMenuIdAction = new QAction(QIcon::fromTheme("user-identity"),
-                                           postAuthorID, this);
-    avatarMenuIdAction->setDisabled(true);
+                                           postAuthorId, this);
+    avatarMenuIdAction->setSeparator(true); // Make it nicer and not clickable
     avatarMenu->addAction(avatarMenuIdAction);
-    avatarMenu->addSeparator();
 
     avatarMenu->addAction(QIcon::fromTheme("internet-web-browser"),
                           tr("Open %1's profile in web browser")
@@ -517,6 +583,13 @@ void Post::createAvatarMenu()
                           tr("Copy post link to clipboard"),
                           this,
                           SLOT(copyPostUrlToClipboard()));
+
+    avatarMenu->addSeparator();
+
+    avatarMenu->addAction(QIcon::fromTheme("format-text-color"),
+                          tr("Normalize text colors"),
+                          this,
+                          SLOT(normalizeTextFormat()));
 }
 
 
@@ -535,7 +608,7 @@ void Post::setFollowUnfollow()
                 this, SLOT(unfollowUser()));
         disconnect(avatarMenuFollowAction, SIGNAL(triggered()),
                    this, SLOT(followUser()));
-        qDebug() << "post author followed, connecting to UNFOLLOW()" << this->postAuthorID;
+        qDebug() << "post author followed, connecting to UNFOLLOW()" << this->postAuthorId;
     }
     else
     {
@@ -545,12 +618,20 @@ void Post::setFollowUnfollow()
                 this, SLOT(followUser()));
         disconnect(avatarMenuFollowAction, SIGNAL(triggered()),
                    this, SLOT(unfollowUser()));
-        qDebug() << "post author not followed, connecting to FOLLOW()" << this->postAuthorID;
+        qDebug() << "post author not followed, connecting to FOLLOW()" << this->postAuthorId;
     }
 }
 
 
 
+void Post::setMinMaxHeight(int newMinMaxHeight)
+{
+    // Substract some pixels to account for the row of buttons, etc.
+    this->minMaxHeight = newMinMaxHeight - 80;
+}
+
+
+
 /*
  * Set the post contents, and trigger a vertical resize
  *
@@ -561,9 +642,9 @@ void Post::setPostContents()
 
     QString postImage;
     int imageWidth;
-    if (!this->postImageURL.isEmpty())
+    if (!this->postImageUrl.isEmpty())
     {
-        QString imageCachedFilename = MiscHelpers::getCachedImageFilename(postImageURL);
+        QString imageCachedFilename = MiscHelpers::getCachedImageFilename(postImageUrl);
 
         imageWidth = MiscHelpers::getImageWidth(imageCachedFilename);
         // if the image is wider than the post space, make it smaller
@@ -614,18 +695,22 @@ void Post::setPostHeight()
 {
     int height = postText->document()->size().toSize().height() + 12; // +12px error margin
 
-    if (height < 80)
+    if (height < 60)
     {
-        height = 80;
-    }
-    // FIXME: this will be based on a percentage of window height, not hardcoded!
-    if (height > 450)  // Don't allow a post to have a minimum height > 450 px
-    {
-        height = 450;  // Scrollbars might appear
+        height = 60;
     }
 
-    postText->setMinimumHeight(height);
-    postText->setMaximumHeight(height);
+    if (height > this->minMaxHeight)  // Don't allow a post to be too tall
+    {
+        height = this->minMaxHeight;  // Scrollbars might appear
+    }
+
+    // Don't force a specific height if the post is standalone
+    if (!standalone)
+    {
+        postText->setMinimumHeight(height);
+        postText->setMaximumHeight(height);
+    }
 }
 
 
@@ -668,7 +753,7 @@ void Post::enqueueImageForDownload(QString url)
  */
 QString Post::likesURL()
 {
-    return this->postLikesURL;
+    return this->postLikesUrl;
 }
 
 
@@ -685,7 +770,7 @@ void Post::setLikes(QVariantList likesList, int likesCount)
         foreach (QVariant likesMap, likesList)
         {
             peopleString = likesMap.toMap().value("displayName").toString() + ", "
-                    + peopleString;
+                           + peopleString;
         }
 
         // Remove last comma and add "like this"
@@ -752,7 +837,7 @@ void Post::setLikesLabel(int likesCount)
  */
 QString Post::commentsURL()
 {
-    return this->postCommentsURL;
+    return this->postCommentsUrl;
 }
 
 
@@ -803,7 +888,7 @@ void Post::setCommentsLabel(int commentsCount)
  */
 QString Post::sharesURL()
 {
-    return this->postSharesURL;
+    return this->postSharesUrl;
 }
 
 
@@ -819,7 +904,7 @@ void Post::setShares(QVariantList sharesList, int sharesCount)
         foreach (QVariant sharesMap, sharesList)
         {
             peopleString = sharesMap.toMap().value("displayName").toString() + ", "
-                    + peopleString;
+                           + peopleString;
         }
 
         // Remove last comma and add "shared this"
@@ -893,6 +978,9 @@ void Post::setPostUnreadStatus()
         postCreatedAtLabel->setAutoFillBackground(true);
         postCreatedAtLabel->setForegroundRole(QPalette::HighlightedText);
         postCreatedAtLabel->setBackgroundRole(QPalette::Highlight);
+
+        this->setAutoFillBackground(true);
+        this->setBackgroundRole(QPalette::Mid);
     }
     else
     {
@@ -903,6 +991,26 @@ void Post::setPostUnreadStatus()
         postCreatedAtLabel->setAutoFillBackground(false);
         postCreatedAtLabel->setForegroundRole(QPalette::Foreground);
         postCreatedAtLabel->setBackgroundRole(QPalette::Background);
+
+        this->setAutoFillBackground(false);
+        this->setBackgroundRole(QPalette::Window);
+    }
+}
+
+void Post::setPostAsNew()
+{
+    this->postIsUnread = true;
+    setPostUnreadStatus();
+}
+
+void Post::setPostAsRead()
+{
+    if (postIsUnread)
+    {
+        this->postIsUnread = false;
+        emit postRead(); // Inform the Timeline()
+
+        setPostUnreadStatus();
     }
 }
 
@@ -928,13 +1036,7 @@ void Post::resizeEvent(QResizeEvent *event)
  */
 void Post::mousePressEvent(QMouseEvent *event)
 {
-    if (postIsUnread)
-    {
-        this->postIsUnread = false;
-        emit postRead(); // Inform the Timeline()
-
-        setPostUnreadStatus();
-    }
+    setPostAsRead();
 
     event->accept();
 }
@@ -952,6 +1054,36 @@ void Post::leaveEvent(QEvent *event)
     event->accept();
 }
 
+/*
+ * closeEvent, needed when posts are opened in separate window
+ *
+ */
+void Post::closeEvent(QCloseEvent *event)
+{
+    qDebug() << "Post::closeEvent()";
+    this->deleteLater();
+
+    event->accept();
+}
+
+
+void Post::keyPressEvent(QKeyEvent *event)
+{
+    if (event->key() == Qt::Key_Escape)
+    {
+        event->accept();
+
+        if (standalone)
+        {
+            this->close();
+        }
+    }
+    else
+    {
+        event->ignore();
+    }
+}
+
 
 
 ////////////////////////////////////////////////////////////////////////////
@@ -967,7 +1099,7 @@ void Post::likePost(bool like)
 {
     qDebug() << "Post::likePost()" << (like ? "like" : "unlike");
 
-    this->pController->likePost(this->postID, this->postType, like);
+    this->pController->likePost(this->postId, this->postType, like);
 
     this->fixLikeButton(like ? "true" : "false");
 
@@ -1001,7 +1133,7 @@ void Post::getAllLikes()
     disconnect(pController, SIGNAL(likeSet()),
                this, SLOT(getAllLikes()));
 
-    this->pController->getPostLikes(this->postLikesURL);
+    this->pController->getPostLikes(this->postLikesUrl);
 }
 
 
@@ -1036,13 +1168,27 @@ void Post::sendComment(QString comment)
     qDebug() << "About to publish this comment:" << comment;
 
     this->pController->addComment(MiscHelpers::cleanupHtml(comment),
-                                  this->postID, this->postType);
+                                  this->postId, this->postType);
 }
 
 
 void Post::getAllComments()
 {
-    this->pController->getPostComments(this->postCommentsURL);
+    this->pController->getPostComments(this->postCommentsUrl);
+}
+
+/*
+ * Set all comments received from signal, when post is a separate window,
+ * and not handled by Timeline()
+ *
+ */
+void Post::setAllComments(QVariantList commentsList, QString originatingPostUrl)
+{
+    QString originatingPostCleanUrl = originatingPostUrl.split("?").at(0);
+    if (this->commentsURL() == originatingPostCleanUrl)
+    {
+        this->setComments(commentsList);
+    }
 }
 
 
@@ -1059,22 +1205,43 @@ void Post::sharePost()
 
     if (confirmation == 0)
     {
-        qDebug() << "Sharing this post";
-        this->pController->sharePost(this->postID, this->postType);
+        qDebug() << "Sharing this post:" << this->postId;
+        this->pController->sharePost(this->postId, this->postType);
     }
     else
     {
-        qDebug() << "Confirmation cancelled, not sharing";
+        qDebug() << "Confirmation canceled, not sharing";
     }
 }
 
+void Post::unsharePost()
+{
+    int confirmation = QMessageBox::question(this, tr("Unshare post?"),
+                                             tr("Do you want to unshare %1's post?").arg(this->postAuthorNameLabel->text()),
+                                             tr("&Yes, unshare it"), tr("&No"),
+                                             "", 1, 1);
+
+    if (confirmation == 0)
+    {
+        qDebug() << "Unsharing this post:" << this->postId;
+        this->pController->unsharePost(this->postId, this->postType);
+
+        this->setDisabled(true); // Disable the widget, to let user know it's been unshared
+    }
+    else
+    {
+        qDebug() << "Confirmation canceled, will not unshare";
+    }
+}
+
+
 /*
  * Set the Publisher in editing mode with this post's contents
  *
  */
 void Post::editPost()
 {
-    emit postEditRequested(this->postID,
+    emit postEditRequested(this->postId,
                            this->postOriginalText,
                            this->postTitle);
 }
@@ -1094,7 +1261,7 @@ void Post::deletePost()
     if (confirmation == 0)
     {
         qDebug() << "Deleting post";
-        this->pController->deletePost(this->postID, this->postType);
+        this->pController->deletePost(this->postId, this->postType);
 
         this->setDisabled(true); // disable... maybe hide?
     }
@@ -1152,18 +1319,18 @@ void Post::showHighlightedURL(QUrl url)
 
 void Post::openAuthorProfileInBrowser()
 {
-    QDesktopServices::openUrl(this->postAuthorURL);
+    QDesktopServices::openUrl(this->postAuthorUrl);
 }
 
 
 void Post::openPostInBrowser()
 {
-    QDesktopServices::openUrl(this->postURL);
+    QDesktopServices::openUrl(this->postUrl);
 }
 
 void Post::copyPostUrlToClipboard()
 {
-    QApplication::clipboard()->setText(this->postURL);
+    QApplication::clipboard()->setText(this->postUrl);
 }
 
 
@@ -1171,7 +1338,7 @@ void Post::copyPostUrlToClipboard()
 
 void Post::followUser()
 {
-    this->pController->followContact(this->postAuthorID);
+    this->pController->followContact(this->postAuthorId);
 
     postAuthorFollowed = true; // FIXME: should wait until confirmed by server...
     this->setFollowUnfollow();
@@ -1182,12 +1349,12 @@ void Post::unfollowUser()
 {
     int confirmation = QMessageBox::question(this, tr("Stop following?"),
                                              tr("Are you sure you want to stop following %1?")
-                                             .arg(this->postAuthorID),
+                                             .arg(this->postAuthorId),
                                              tr("&Yes, stop following"), tr("&No"), "", 1, 1);
 
     if (confirmation == 0)
     {
-        this->pController->unfollowContact(this->postAuthorID);
+        this->pController->unfollowContact(this->postAuthorId);
 
         postAuthorFollowed = false; // FIXME: should wait until confirmed by server...
         this->setFollowUnfollow();
@@ -1195,6 +1362,24 @@ void Post::unfollowUser()
 }
 
 
+/*
+ * Normalize text colors; Used from menu when a post
+ * has white text with white background, or similar
+ *
+ */
+void Post::normalizeTextFormat()
+{
+    postText->selectAll();
+
+    postText->setTextColor(qApp->palette().windowText().color());
+    postText->setTextBackgroundColor(QColor(Qt::transparent));
+
+    // Select 'none'
+    postText->moveCursor(QTextCursor::Start);
+    postText->textCursor().select(QTextCursor::WordUnderCursor);
+}
+
+
 
 /*
  * Trigger a resizeEvent, which will call
