@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@
 #include "pumpcontroller.h"
 #include "commenterblock.h"
 #include "imageviewer.h"
+#include "asactivity.h"
 
 
 class Post : public QFrame
@@ -53,16 +54,16 @@ class Post : public QFrame
 
 public:
     Post(PumpController *pumpController,
-         QMap<QString,QString> postData,
-         QVariantList lastLikesVariantList,
-         QVariantList lastCommentsVariantList,
-         QVariantList lastSharesVariantList,
+         ASActivity *activity,
+         bool isStandalone = false,
          QWidget *parent = 0);
     ~Post();
 
     void createAvatarMenu();
     void setFollowUnfollow();
 
+    void setMinMaxHeight(int newMinMaxHeight);
+
     void setPostContents();
     void setPostHeight();
     void enqueueImageForDownload(QString url);
@@ -80,6 +81,8 @@ public:
     void setSharesLabel(int resharesCount);
 
     void setPostUnreadStatus();
+    void setPostAsNew();
+    void setPostAsRead();
 
 
 signals:
@@ -98,8 +101,11 @@ public slots:
     void commentOnPost();
     void sendComment(QString comment);
     void getAllComments();
+    void setAllComments(QVariantList commentsList,
+                        QString originatingPostUrl);
 
     void sharePost();
+    void unsharePost();
 
     void editPost();
 
@@ -115,6 +121,8 @@ public slots:
     void followUser();
     void unfollowUser();
 
+    void normalizeTextFormat();
+
     void triggerResize();
 
     void redrawAvatar(QString avatarUrl, QString avatarFilename);
@@ -124,6 +132,8 @@ protected:
     virtual void resizeEvent(QResizeEvent *event);
     virtual void mousePressEvent(QMouseEvent *event);
     virtual void leaveEvent(QEvent *event);
+    virtual void closeEvent(QCloseEvent *event);
+    virtual void keyPressEvent(QKeyEvent *event);
 
 
 private:
@@ -131,15 +141,17 @@ private:
     QVBoxLayout *leftColumnLayout;
     QVBoxLayout *rightColumnLayout;
 
-    QString postID;
+    QString postId;
     QString postType;
-    QString postURL;
-    QString postAuthorID;
+    QString postUrl;
+    QString postAuthorId;
     QString postAuthorName;
-    QString postAuthorURL;
+    QString postAuthorUrl;
     QString postAuthorAvatarUrl;
     bool postAuthorFollowed;
 
+    QString postSharedById;
+
     bool postIsOwn;
     bool postIsUnread;
 
@@ -150,6 +162,7 @@ private:
 
     QLabel *postAuthorNameLabel;
     QLabel *postCreatedAtLabel;
+    QLabel *postLocationLabel;
     QLabel *postToLabel;
     QLabel *postCCLabel;
     QLabel *postIsSharedLabel;
@@ -173,16 +186,18 @@ private:
     QPushButton *deleteButton;
 
     QString postTitle;
-    QString postImageURL;
+    QString postImageUrl;
     QString postOriginalText;
 
     int postWidth;
+    int minMaxHeight;
 
-    QString postLikesURL;
-    QString postCommentsURL;
-    QString postSharesURL;
+    QString postLikesUrl;
+    QString postCommentsUrl;
+    QString postSharesUrl;
     QStringList pendingImagesList;
 
+    bool standalone;
 
     PumpController *pController;
     CommenterBlock *commenter;
