@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -32,6 +32,23 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
     this->pController = pumpController;
 
+
+    QFont infoFont;
+    infoFont.setPointSize(infoFont.pointSize() - 1);
+
+    webfingerLabel = new QLabel();
+    webfingerLabel->setFont(infoFont);
+    webfingerLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
+    webfingerLabel->setToolTip(tr("This is your Pump address"));
+
+    emailLabel = new QLabel();
+    emailLabel->setFont(infoFont);
+    emailLabel->setTextInteractionFlags(Qt::TextBrowserInteraction);
+    emailLabel->setToolTip(tr("This is the e-mail address associated with your account, "
+                              "for things such as notifications and password recovery")
+                           + "<b></b>"); // Make the tooltip HTML so it gets wordwrap
+
+
     avatarLabel = new QLabel();
     avatarLabel->setPixmap(QIcon::fromTheme("user-properties").pixmap(64, 64));
 
@@ -59,6 +76,18 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
     connect(cancelButton, SIGNAL(clicked()), this, SLOT(hide()));
 
 
+    // ESC to cancel, too
+    cancelAction = new QAction(this);
+    cancelAction->setShortcut(QKeySequence(Qt::Key_Escape));
+    connect(cancelAction, SIGNAL(triggered()),
+            this, SLOT(hide()));
+    this->addAction(cancelAction);
+
+
+    this->avatarLayout = new QHBoxLayout();
+    avatarLayout->addWidget(avatarLabel);
+    avatarLayout->addWidget(changeAvatarButton);
+
 
     this->bottomLayout = new QHBoxLayout();
     bottomLayout->setAlignment(Qt::AlignRight);
@@ -67,12 +96,14 @@ ProfileEditor::ProfileEditor(PumpController *pumpController,
 
 
     this->mainLayout = new QFormLayout();
-    mainLayout->setSpacing(8);
-    mainLayout->addRow(tr("Avatar"),     avatarLabel);
-    mainLayout->addWidget(changeAvatarButton);
-    mainLayout->addRow(tr("Full &Name"), fullNameLineEdit);
-    mainLayout->addRow(tr("&Hometown"),  hometownLineEdit);
-    mainLayout->addRow(tr("&Bio"),       bioTextEdit);
+    mainLayout->setVerticalSpacing(8);
+    mainLayout->addRow(tr("Webfinger ID"), webfingerLabel);
+    mainLayout->addRow(tr("E-mail"),       emailLabel);
+
+    mainLayout->addRow(tr("Avatar"),       avatarLayout);
+    mainLayout->addRow(tr("Full &Name"),   fullNameLineEdit);
+    mainLayout->addRow(tr("&Hometown"),    hometownLineEdit);
+    mainLayout->addRow(tr("&Bio"),         bioTextEdit);
 
     mainLayout->addRow(bottomLayout);
 
@@ -95,10 +126,24 @@ ProfileEditor::~ProfileEditor()
  * Fill the fields from received info
  *
  */
-void ProfileEditor::setProfileData(QString avatarURL, QString fullName, QString hometown, QString bio)
+void ProfileEditor::setProfileData(QString avatarUrl, QString fullName,
+                                   QString hometown, QString bio,
+                                   QString eMail)
 {
-    this->currentAvatarURL = avatarURL;
+    this->webfingerLabel->setText(pController->currentUserId());
+    if (eMail.isEmpty())
+    {
+        this->emailLabel->setText("<" + tr("Not set",
+                                           "In reference to the e-mail "
+                                           "not being set for the account")
+                                  + ">");
+    }
+    else
+    {
+        this->emailLabel->setText(eMail);
+    }
 
+    this->currentAvatarURL = avatarUrl;
     QString avatarFilename = MiscHelpers::getCachedAvatarFilename(this->currentAvatarURL);
     if (QFile::exists(avatarFilename))
     {
