@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -30,6 +30,7 @@
 #include <QPushButton>
 #include <QFileDialog>
 #include <QMessageBox>
+#include <QAction>
 
 #include <QDebug>
 
@@ -47,8 +48,9 @@ public:
                            QWidget *parent = 0);
     ~ProfileEditor();
 
-    void setProfileData(QString avatarURL, QString fullName,
-                        QString hometown, QString bio);
+    void setProfileData(QString avatarUrl, QString fullName,
+                        QString hometown, QString bio,
+                        QString eMail);
 
 
 signals:
@@ -64,12 +66,16 @@ private:
 
 
     QFormLayout *mainLayout;
+    QHBoxLayout *avatarLayout;
     QHBoxLayout *bottomLayout;
 
     QLabel *avatarLabel;
     QPushButton *changeAvatarButton;
     bool avatarChanged;
 
+    QLabel *webfingerLabel;
+    QLabel *emailLabel;
+
     QLineEdit *fullNameLineEdit;
     QLineEdit *hometownLineEdit;
     QTextEdit *bioTextEdit;
@@ -77,6 +83,8 @@ private:
     QPushButton *saveButton;
     QPushButton *cancelButton;
 
+    QAction *cancelAction;
+
     QString currentAvatarURL;
     QString newAvatarFilename;
     QString newAvatarContentType;
