@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -21,7 +21,6 @@
 #include "publisher.h"
 
 Publisher::Publisher(PumpController *pumpController,
-                     int publisherType,
                      QWidget *parent) : QWidget(parent)
 {
     this->pController = pumpController;
@@ -49,9 +48,8 @@ Publisher::Publisher(PumpController *pumpController,
             this, SLOT(updateToCcFields(QString,QStringList)));
 
 
-    mainLayout = new QGridLayout();
 
-    titleLabel = new QLabel(tr("Title:"));
+    titleLabel = new QLabel(tr("Title") + ":");
     titleLabel->setSizePolicy(QSizePolicy::Minimum,
                               QSizePolicy::Maximum);
 
@@ -59,16 +57,20 @@ Publisher::Publisher(PumpController *pumpController,
     titleLineEdit->setSizePolicy(QSizePolicy::MinimumExpanding,
                                  QSizePolicy::Maximum);
     titleLineEdit->setPlaceholderText(tr("Optional title for the post"));
-    titleLineEdit->setToolTip(tr("Title for the post"));
+    titleLineEdit->setToolTip(tr("Title for the post. Setting a title "
+                                 "helps make the Meanwhile feed "
+                                 "more informative.") + "<b></b>");
 
 
     pictureLabel = new QLabel();
-    pictureLabel->setScaledContents(true);
+    pictureLabel->setAlignment(Qt::AlignCenter);
+    //pictureLabel->setScaledContents(true);
     pictureLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Raised);
     pictureLabel->hide();
 
 
     pictureInfoLabel = new QLabel();
+    pictureInfoLabel->setAlignment(Qt::AlignTop | Qt::AlignLeft);
 
     selectPictureButton = new QPushButton(QIcon::fromTheme("insert-image"),
                                           tr("Select Picture..."));
@@ -94,6 +96,9 @@ Publisher::Publisher(PumpController *pumpController,
     connect(composerBox, SIGNAL(editingFinished()),  this, SLOT(sendPost()));
     connect(composerBox, SIGNAL(editingCancelled()), this, SLOT(setMinimumMode()));
 
+    // Add formatting button exported from Composer
+    this->toolsButton = composerBox->getToolsButton();
+
 
     // To... menu
     toPublicAction = new QAction(tr("Public"), this);
@@ -216,66 +221,44 @@ Publisher::Publisher(PumpController *pumpController,
 
 
     // Now the layout, starting with the Title field and "picture mode" stuff
-    mainLayout->addWidget(titleLabel,          0, 0, 1, 1, Qt::AlignTop);
-    mainLayout->addWidget(titleLineEdit,       0, 1, 1, 5, Qt::AlignTop);
-    mainLayout->addWidget(pictureLabel,        0, 6, 2, 2);
-    mainLayout->addWidget(pictureInfoLabel,    1, 0, 1, 2, Qt::AlignBottom);
-    mainLayout->addWidget(selectPictureButton, 1, 2, 1, 3, Qt::AlignBottom | Qt::AlignRight);
+    titleLayout = new QHBoxLayout();
+    titleLayout->addWidget(titleLabel);
+    titleLayout->addWidget(titleLineEdit);
+    titleLayout->addSpacing(12);
+    titleLayout->addWidget(toolsButton);
 
-    // The rest depends on the publisher type
-    switch (publisherType)
-    {
-    case 1: // second layout, buttons around
-        mainLayout->addWidget(toSelectorButton, 2, 0, 1, 1, Qt::AlignTop);
-        mainLayout->addWidget(ccSelectorButton, 3, 0, 1, 1, Qt::AlignTop);
-        mainLayout->addWidget(pictureButton,    4, 0, 1, 1, Qt::AlignTop);
-        mainLayout->addWidget(composerBox,      2, 1, 3, 6); // 3 rows, 6 columns
-        mainLayout->addWidget(postButton,       4, 7, 3, 1); // 3 rows
-        postButton->setSizePolicy(QSizePolicy::MinimumExpanding,
-                                  QSizePolicy::MinimumExpanding);
-        break;
+    mainLayout = new QGridLayout();
+    mainLayout->setVerticalSpacing(1);
+    mainLayout->setContentsMargins(1, 1, 1, 1);
 
-    case 2: // Third layout, buttons on right side
-        mainLayout->addWidget(composerBox,      2, 0, 3, 6); // 3 rows, 6 columns
-        mainLayout->addWidget(toSelectorButton, 2, 6, 1, 1, Qt::AlignTop);
-        mainLayout->addWidget(ccSelectorButton, 3, 6, 1, 1, Qt::AlignTop);
-        mainLayout->addWidget(pictureButton,    4, 6, 1, 1, Qt::AlignTop);
-        mainLayout->addWidget(postButton,       4, 7, 2, 1);
-        postButton->setSizePolicy(QSizePolicy::MinimumExpanding,
-                                  QSizePolicy::MinimumExpanding);
-        break;
+    mainLayout->addLayout(titleLayout,         0, 0, 1, 8, Qt::AlignTop | Qt::AlignLeft);
+    mainLayout->addWidget(pictureLabel,        1, 0, 2, 4);
+    mainLayout->addWidget(pictureInfoLabel,    1, 4, 1, 4, Qt::AlignTop);
+    mainLayout->addWidget(selectPictureButton, 2, 4, 1, 4, Qt::AlignBottom | Qt::AlignLeft);
 
+    mainLayout->addWidget(composerBox,         3, 0, 3, 8); // 3 rows, 8 columns
 
-    case 0: // First (default) layout
-        // just let it jump to default, so incorrect values go to default
+    mainLayout->addWidget(toSelectorButton,    6, 0, 1, 1, Qt::AlignLeft);
+    mainLayout->addWidget(ccSelectorButton,    6, 1, 1, 1, Qt::AlignLeft);
+    mainLayout->addWidget(pictureButton,       6, 3, 1, 2, Qt::AlignLeft);
+    mainLayout->addWidget(statusInfoLabel,     6, 5, 3, 2, Qt::AlignCenter);
+    mainLayout->addWidget(postButton,          6, 7, 1, 1);
 
-    default:
-        mainLayout->addWidget(composerBox,      2, 0, 3, 8); // 3 rows, 8 columns
-        mainLayout->addWidget(toSelectorButton, 5, 0, 1, 1, Qt::AlignLeft);
-        mainLayout->addWidget(ccSelectorButton, 5, 1, 1, 1, Qt::AlignLeft);
-        mainLayout->addWidget(pictureButton,    5, 3, 1, 2, Qt::AlignLeft);
-        mainLayout->addWidget(postButton,       5, 7, 1, 1);
-
-        break;
-
-    }
 
     // The 2 labels holding people's names, if any
-    mainLayout->addWidget(toAudienceLabel, 6, 0, 1, 1);
-    mainLayout->addWidget(ccAudienceLabel, 6, 1, 1, 1);
+    mainLayout->addWidget(toAudienceLabel, 7, 0, 1, 1);
+    mainLayout->addWidget(ccAudienceLabel, 7, 1, 1, 1);
 
     // The 2 labels holding "public/followers", if selected
-    mainLayout->addWidget(toPublicFollowersLabel, 7, 0, 1, 1);
-    mainLayout->addWidget(ccPublicFollowersLabel, 7, 1, 1, 1);
+    mainLayout->addWidget(toPublicFollowersLabel, 8, 0, 1, 1);
+    mainLayout->addWidget(ccPublicFollowersLabel, 8, 1, 1, 1);
 
-    // the status info label
-    mainLayout->addWidget(statusInfoLabel, 5, 5, 3, 2, Qt::AlignCenter);
-
-    // The "cancel" button
-    mainLayout->addWidget(cancelButton,    7, 7, 1, 1);
+    // The "Cancel post" button
+    mainLayout->addWidget(cancelButton,        8, 7, 1, 1);
 
     this->setLayout(mainLayout);
 
+
     this->setMinimumMode();
 
     qDebug() << "Publisher created";
@@ -395,7 +378,7 @@ QMap<QString,QString> Publisher::getAudienceMap()
     // To: Followers is checked
     if (toFollowersAction->isChecked())
     {
-        audienceMap.insertMulti("to|collection", this->pController->currentFollowersURL());
+        audienceMap.insertMulti("to|collection", this->pController->currentFollowersUrl());
     }
 
 
@@ -422,7 +405,7 @@ QMap<QString,QString> Publisher::getAudienceMap()
     // Last check: if CC: Followers is checked, or nothing is, add Followers
     if (ccFollowersAction->isChecked() || audienceMap.isEmpty())
     {
-        audienceMap.insertMulti("cc|collection", this->pController->currentFollowersURL());
+        audienceMap.insertMulti("cc|collection", this->pController->currentFollowersUrl());
     }
 
 
@@ -441,19 +424,20 @@ void Publisher::setMinimumMode()
 {
     qDebug() << "setting Publisher to minimum mode";
 
-    this->postButton->setFocus(); // give focus to button,
+    this->postButton->setFocus(); // Give focus to button,
                                   // in case user shared with Ctrl+Enter
 
-    // disable possible scrollbars
+    // Disable possible scrollbars
     this->composerBox->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     this->composerBox->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
 
     // ~1 row
-    int composerHeight = (this->composerBox->fontInfo().pixelSize() + 4) * 3;
-    this->setMinimumHeight(composerHeight);
-    this->setMaximumHeight(composerHeight);
-    // FIXME: maybe should resize composerBox too/instead
-    //this->composerBox->setMaximumHeight(composerHeight);
+    int composerHeight = composerBox->getMessageLabelHeight();
+    this->composerBox->setMinimumHeight(composerHeight);
+    this->composerBox->setMaximumHeight(composerHeight);
+
+    this->setMinimumHeight(composerHeight + 2);
+    this->setMaximumHeight(composerHeight + 2);
 
 
     this->audienceSelectorTo->resetLists();
@@ -510,6 +494,9 @@ void Publisher::setMinimumMode()
     titleLabel->hide();
     this->titleLineEdit->clear();
     titleLineEdit->hide();
+
+    toolsButton->hide();
+
     this->statusInfoLabel->clear();
     statusInfoLabel->hide();
     this->pictureButton->hide();
@@ -551,8 +538,11 @@ void Publisher::setFullMode()
     this->titleLabel->show();
     this->titleLineEdit->show();
 
+    this->toolsButton->show();
+
     this->composerBox->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     this->composerBox->setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
+    this->composerBox->setMaximumHeight(2048);
     this->setMaximumHeight(2048); // i.e. "unlimited"
 
     this->toSelectorButton->show();
@@ -930,8 +920,8 @@ void Publisher::findPictureFile()
 
             QPixmap imagePixmap = QPixmap(filename);
             // FIXME: check imagePixmap.isNull() ?
-            this->pictureLabel->setPixmap(imagePixmap.scaled(200, 150,
-                                                             Qt::IgnoreAspectRatio,
+            this->pictureLabel->setPixmap(imagePixmap.scaled(320, 180,  // 16:9
+                                                             Qt::KeepAspectRatio,
                                                              Qt::SmoothTransformation));
             QFileInfo fileInfo(filename);
             this->lastUsedDirectory = fileInfo.path();
