@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 #include <QWidget>
 #include <QGridLayout>
+#include <QHBoxLayout>
 #include <QLabel>
 #include <QLineEdit>
 #include <QPushButton>
@@ -44,7 +45,6 @@ class Publisher : public QWidget
 
 public:
     explicit Publisher(PumpController *pumpController,
-                       int publisherType,
                        QWidget *parent = 0);
     ~Publisher();
 
@@ -89,6 +89,7 @@ public slots:
 
 private:
     QGridLayout *mainLayout;
+    QHBoxLayout *titleLayout;
 
     QLabel *titleLabel;
     QLineEdit *titleLineEdit;
@@ -96,6 +97,8 @@ private:
     QPushButton *selectPictureButton;
     QLabel *pictureLabel;
 
+    QPushButton *toolsButton;
+
     Composer *composerBox;
 
     QPushButton *toSelectorButton;
