@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -59,16 +59,22 @@ public:
     explicit PumpController(QObject *parent = 0);
     ~PumpController();
 
-    void setPostsPerPage(int ppp);
+    void setPostsPerPageMain(int ppp);
+    void setPostsPerPageOther(int ppp);
+
     void setUpdatesToTimelineBlocked(bool blocked);
+    void setFilters(QVariantList filterList);
+    QVariantList getCurrentFilters();
 
-    void setNewUserID(QString userID);
-    void setUserCredentials(QString userID);
-    QString currentUserID();
+    void setNewUserId(QString userId);
+    void setUserCredentials(QString userId);
+    QString currentUserId();
     QString currentUsername();
-    QString currentFollowersURL();
+    QString currentFollowersUrl();
+    int currentFollowersCount();
+    int currentFollowingCount();
 
-    void getUserProfile(QString userID);
+    void getUserProfile(QString userId);
     void updateUserProfile(QString avatarUrl, QString fullName,
                            QString hometown, QString bio);
 
@@ -77,13 +83,16 @@ public:
     void notifyAvatarStored(QString avatarUrl, QString avatarFilename);
     void notifyImageStored(QString imageUrl);
 
-    void getContactList(QString listType);
+    void getContactList(QString listType, int offset=0);
     bool userInFollowing(QString contactId);
     void updateInternalFollowingIdList(QStringList idList);
 
     void getListsList();
     void createPersonList(QString name, QString description);
     void deletePersonList(QString id);
+    void getPersonList(QString url);
+    void addPersonToList(QString listId, QString personId);
+    void removePersonFromList(QString listId, QString personId);
 
     void getMainTimeline(int timelineOffset);
     void getDirectTimeline(int timelineOffset);
@@ -94,7 +103,7 @@ public:
     void getPostComments(QString postCommentsURL);
     void getPostShares(QString postSharesURL);
 
-    void getMinorFeed();
+    void getMinorFeed(int offset = 0);
 
     QNetworkRequest prepareRequest(QString url,
                                    QOAuth::HttpMethod method,
@@ -122,6 +131,9 @@ public:
         ListsListRequest,
         CreatePersonListRequest,
         DeletePersonListRequest,
+        PersonListRequest,
+        AddMemberToListRequest,
+        RemoveMemberFromListRequest,
 
         MainTimelineRequest,
         DirectTimelineRequest,
@@ -138,6 +150,7 @@ public:
         LikePostRequest,
         CommentPostRequest,
         SharePostRequest,
+        UnsharePostRequest,
         DeletePostRequest,
         UpdatePostRequest,
 
@@ -162,9 +175,14 @@ signals:
     void authorizationStatusChanged(bool authorized);
 
     void profileReceived(QString avatarURL, QString fullName,
-                         QString hometown, QString bio);
-    void contactListReceived(QString listType, QVariantList contactList);
+                         QString hometown, QString bio,
+                         QString email);
+    void contactListReceived(QString listType, QVariantList contactList,
+                             int totalReceivedCount);
     void listsListReceived(QVariantList listsList);
+    void personListReceived(QVariantList personList, QString listUrl);
+    void personAddedToList(QString id, QString name);
+    void personRemovedFromList(QString id);
 
 
     void mainTimelineReceived(QVariantList postList, int postsPerPage,
@@ -226,12 +244,13 @@ public slots:
     void likePost(QString postID, QString postType, bool like);
     void addComment(QString comment, QString postID, QString postType);
     void sharePost(QString postID, QString postType);
+    void unsharePost(QString postId, QString postType);
     void deletePost(QString postID, QString postType);
 
     void followContact(QString address);
     void unfollowContact(QString address);
 
-
+    void tmpfixmeNotifyQNAMdestroyed(); // FIXME TMP KILL IT!
 
 private:
     QNetworkAccessManager nam;
@@ -249,12 +268,16 @@ private:
     QByteArray tokenSecret;
 
 
-    QString userID;  // Full webfinger address, user@host.tld
+    QString userId;  // Full webfinger address, user@host.tld
     QString userName;
     QString serverURL;
 
     QString userFollowersURL;
+    int userFollowersCount;
+    int userFollowingCount;
     QStringList followingIdList;
+    int totalReceivedFollowers;
+    int totalReceivedFollowing;
 
     QTimer *initialDataTimer;
     int initialDataStep;
@@ -264,8 +287,10 @@ private:
     bool havePersonLists;
 
 
-    int postsPerPage;
+    int postsPerPageMain;
+    int postsPerPageOther;
     bool updatesToTimelineBlocked;
+    QVariantList currentFilters;
 
 
     // For multi-step operations in posts
