@@ -1,6 +1,6 @@
 /*
  *   This file is part of Dianara
- *   Copyright 2012-2013  JanKusanagi <janjabber@gmail.com>
+ *   Copyright 2012-2014  JanKusanagi <janjabber@gmail.com>
  *
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -31,6 +31,8 @@
 #include <QDebug>
 
 #include "pumpcontroller.h"
+#include "asobject.h"
+#include "asactivity.h"
 #include "post.h"
 
 
@@ -48,8 +50,11 @@ public:
     void requestTimelinePage();
     void updateCurrentPageNumber();
 
+    void setMinMaxHeightForPosts(int newMinMaxHeightForPosts);
     void resizePosts();
 
+    void markPostsAsRead();
+
 
     enum TimelineTypes
     {
@@ -91,8 +96,6 @@ public slots:
     void decreaseUnreadPostsCount();
 
 protected:
-    //virtual void resizeEvent(QResizeEvent *event);
-
 
 private:
     QVBoxLayout *mainLayout;
@@ -114,8 +117,11 @@ private:
     int timelineOffset;
     int postsPerPage;
     int unreadPostsCount;
+    bool postIsNew;
 
-    QString previousNewestPostID;
+    int minMaxHeightForPosts;
+
+    QString previousNewestPostId;
 
     QList<Post *> postsInTimeline;
 };
